/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2005 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna.biz/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.sesame.admin;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import java.text.NumberFormat;

import org.openrdf.sesame.constants.RDFFormat;
import org.openrdf.sesame.sail.RdfRepository;

public abstract class Upload {

	// Every so many milli seconds, a status report will be written.
	protected static final int STATUS_INTERVAL = 60 * 1000;

	protected RdfRepository _rdfRepository;

	protected NumberFormat _nf;

	/**
	 * Creates a new Upload that will use the supplied RdfRepository for
	 * administrating the data.
	 *
	 * @exception IllegalArgumentException If the supplied rdfRepository is equal
	 * to null.
	 **/
	public Upload(RdfRepository rdfRepository) {
		if (rdfRepository == null) {
			throw new IllegalArgumentException("rdfRepository must not be null");
		}
		_rdfRepository = rdfRepository;

		_nf = NumberFormat.getInstance();
	}

	/**
	 * Reads and parses a XML-serialized RDF file from the supplied
	 * InputStream and adds the triples in the database to which the
	 * RdfRepository connects.
	 *
	 * @return the number of processed statements
	 **/
	public abstract int addRdfModel(
		InputStream in, String baseURL,
		AdminListener report, RDFFormat dataFormat, boolean verifyInput)
		throws IOException, UpdateException;

	public abstract int addRdfModel(
		Reader reader, String baseURL,
		AdminListener report, RDFFormat dataFormat, boolean verifyInput)
		throws IOException, UpdateException;
}
