/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2005 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna.biz/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.sesame.constants;

import org.openrdf.util.Enumeration;

/**
 * A type-safe enumeration class for query response formats.
 *
 * @author Arjohn Kampman
 * @version $Revision: 1.3 $
 */
public final class QueryResultFormat extends Enumeration {

/*------------------+
| Static stuff      |
+------------------*/

	/**
	 * Constant representing XML format.
	 **/
	public static final QueryResultFormat XML = new QueryResultFormat("xml");

	/**
	 * Constant representing HTML format.
	 **/
	public static final QueryResultFormat HTML = new QueryResultFormat("html");

	/**
	 * Constant representing RDF format.
	 **/
	public static final QueryResultFormat RDF = new QueryResultFormat("rdf");

	/**
	 * Constant representing binary format.
	 **/
	public static final QueryResultFormat BINARY = new QueryResultFormat("binary");

	/**
	 * A QueryResultFormat array containing all possible values.
	 **/
	private static Enumeration[] _values = new QueryResultFormat[] {XML, HTML, RDF, BINARY};

	/**
	 * Returns a QueryResultFormat constant for the specified value.
	 *
	 * @param value The String-representation of a QueryResultFormat constant.
	 * @return A QueryResultFormat object, or <tt>null</tt> if the specified
	 * value could not be resolved to a QueryResultFormat object.
	 **/
	public static QueryResultFormat forValue(String value) {
		return (QueryResultFormat)_forValue(_values, value);
	}

/*------------------+
| Non-static stuff  |
+------------------*/

	/**
	 * Creates a new QueryResultFormat object.
	 **/
	private QueryResultFormat(String value) {
		super(value);
	}
}
