/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2005 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna.biz/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.sesame.query;

import java.io.IOException;

import org.openrdf.model.Resource;
import org.openrdf.model.URI;
import org.openrdf.model.Value;
import org.openrdf.model.ValueFactory;

import org.openrdf.sesame.sail.query.QueryAnswerListener;

/**
 * An adapter translating QueryAnswerListener (QAL) method calls to
 * GraphQueryResultListener (GQRL) method calls.
 **/
public class QAL2GQRL implements QueryAnswerListener {

	protected GraphQueryResultListener _listener;
	protected ValueFactory _valFactory;

	/**
	 * Creates a new SfwQuery.
	 *
	 * @param listener A GraphQueryResultListener.
	 * @param valFactory A ValueFactory
	 **/
	public QAL2GQRL(GraphQueryResultListener listener, ValueFactory valFactory) {
		_listener = listener;
		_valFactory = valFactory;
	}

	public void clear()
	{
	}

	public void queryAnswer(Value[] values)
		throws IOException
	{
		Resource subject = (Resource)values[0];
		URI predicate = (URI)values[1];
		Value object = values[2];
		
		_listener.triple(subject, predicate, object);
		
		/*
		ValueExpr subject = (ValueExpr)values[0];  
		ValueExpr predicate = (ValueExpr)values[1];
		ValueExpr object = (ValueExpr)values[2];
		
		// check if subject is an anonymous variable. In such cases a
		// new bnode should be constructed.
		if (subject instanceof Var) {
			Var subjVar = (Var)subject;
			
			if (subjVar.isAnonymous() && !subjVar.hasValue()) {
				subjVar.setValue(_valFactory.createBNode());
			}
		}
		
		// check if object is an anonymous  variable. In such cases a
		// new bnode should be constructed.		
		if (object instanceof Var) {
			Var objVar = (Var)object;
			
			if (objVar.isAnonymous() && !objVar.hasValue()) {
				objVar.setValue(_valFactory.createBNode());
			}
		}		

		Value subj = subject.getValue();
		Value pred = predicate.getValue();
		Value obj  = object.getValue();

		if (subj instanceof Resource && // includes check subj != null
			pred instanceof URI && // includes check pred != null
			obj != null)
		{
			_listener.triple((Resource)subj, (URI)pred, obj);
		}
		
		// reset the values of anonymous vars that contain bnodes for the next query 
		// answer.
		if (subject instanceof Var) {
			Var subjVar = (Var)subject;
			
			if (subjVar.isAnonymous() && subjVar.getValue() instanceof BNode) {
				subjVar.setValue(null);
			}
		}
		if (object instanceof Var) {
			Var objVar = (Var)object;
			
			if (objVar.isAnonymous() && objVar.getValue() instanceof BNode) {
				objVar.setValue(null);
			}
		}	
		*/
	}

	public void reportError(String msg)
		throws IOException, QueryEvaluationException
	{
		_listener.reportError(msg);
	}
}
