/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2005 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna.biz/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.sesame.query;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.openrdf.sesame.sail.RdfSource;
import org.openrdf.sesame.sail.query.ProjectionItem;
import org.openrdf.sesame.sail.query.QueryComponent;
import org.openrdf.sesame.sail.query.SailQueryException;
import org.openrdf.sesame.sail.query.Var;

/**
 * A TableQuery has a result set in which each row is a set of variable bindings.
 **/
public class TableQuery extends Query {

	protected static List _filterNonVars(List projectionItemList) {
		List result = new ArrayList();

		for (int i = 0; i < projectionItemList.size(); i++) {
			ProjectionItem pj = (ProjectionItem)projectionItemList.get(i);
			if (pj.getValueExpr() instanceof Var) {
				result.add(pj);
			}
		}

		return result;
	}

	protected List _pathExprProjection;
	
	/**
	 * Creates a new SfwQuery.
	 *
	 * @param qc A QueryComponent representing the actual query.
	 **/
	public TableQuery(QueryComponent qc) {
		super(qc);
	}

	public void evaluate(RdfSource rdfSource, TableQueryResultListener listener)
		throws QueryEvaluationException
	{
		try {
			listener.startTableQueryResult(_qc.getColumnHeaders());
			_qc.evaluate(rdfSource, new QAL2TQRL(_pathExprProjection, listener));
			listener.endTableQueryResult();
		}
		catch (SailQueryException e) {
			throw new QueryEvaluationException(e);
		}
		catch (IOException e) {
			throw new QueryEvaluationException(e);
		}
	}

	public String toString() {
		return "TableQuery [" + super.toString() + "]";
	}
}
