/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2005 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna.biz/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.sesame.query.rql.model;

import org.openrdf.model.Value;

import org.openrdf.sesame.query.QueryEvaluationException;
import org.openrdf.sesame.query.TableQueryResultListener;
import org.openrdf.sesame.sail.RdfSchemaSource;
import org.openrdf.sesame.sail.ValueIterator;
import org.openrdf.sesame.sail.util.EmptyValueIterator;
import org.openrdf.sesame.sail.util.SingleValueIterator;

/**
 * A DataVar is a variable that holds information on the actual metadata (as
 * opposed to the schema information).
 */
public class DataVar extends Var implements DataQuery {

	public DataVar(String name) {
		super(name);
	}

	public void evaluate(RdfSchemaSource rss, TableQueryResultListener listener)
			throws QueryEvaluationException
	{
		throw new QueryEvaluationException(
				"DataVar can not be used as top-level query");
	}

	public ValueIterator getResources(RdfSchemaSource rss) {
		return getInstances(rss);
	}

	public ValueIterator getInstances(RdfSchemaSource rss) {
		Value v = getValue();
		if (v == null) {
			return new EmptyValueIterator();
		}
		return new SingleValueIterator(v);
	}
}