/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2005 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna.biz/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.sesame.sailimpl.nativerdf.btree;

import java.io.IOException;

/**
 * An iterator that iterates over the values in a BTree.
 *
 * @see BTree
 **/
public interface BTreeIterator {

	/**
	 * Returns the next value in the BTree.
	 *
	 * @return A value that is stored in the BTree, or <tt>null</tt> if all
	 * values have been returned.
	 * @exception IOException In case an I/O error occurred.
	 **/
	public byte[] next()
		throws IOException;

	/**
	 * Closes the iterator, freeing any resources that it uses. Once closes, the
	 * iterator will not return any more values.
	 *
	 * @exception IOException In case an I/O error occurred.
	 **/
	public void close()
		throws IOException;
}
