package com.mkdoc.jspider;

/*
    Created:    2005-07-12
    Issued:     2005-10-05
    Modified:   2005-11-02

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import net.javacoding.jspider.core.util.config.ConfigurationFactory;
import net.javacoding.jspider.core.util.config.JSpiderConfiguration;
import net.javacoding.jspider.core.util.config.PropertySet;

import com.mkdoc.util.AbstractApplicationContext;
import com.mkdoc.util.ApplicationContext;

import java.io.File;

/**
 *  A plugin application context.
 *  <p>
 *    A wrapper around a JSpider <code>PropertySet</code> type.
 *  </p>
 *  @version    0.4 2005-10-14
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class PluginApplicationContext extends AbstractApplicationContext
                                           implements ApplicationContext {

    /**
     *  Provide a wrapper for a JSpider <code>PropertySet</code>
     *  @since  Version 0.1 2005-07-12
     */
    private final PropertySet propertySet;

    /**
     *  Provide a wrapper for a JSpider <code>PropertySet</code>
     *  @param  propertySet A property set obtained from the JSpider engine.
     *  @since  Version 0.1 2005-07-12
     */
    public PluginApplicationContext(final PropertySet propertySet) {

        super();

        if (propertySet == null) {

            throw new IllegalArgumentException(
                        "Null property set not permitted.");
        }
        else {

            this.propertySet = propertySet;
        }
    }

    /**
     *  Get a named parameter value.
     *  @param  name    The name of the parameter to look up.
     *  @return The value of the named parameter, or <code>null</code> if not
     *          found.
     *  @since  Version 0.1 2005-07-12
     */
    public final String getStringParameter(final String name) {

        return propertySet.getString(name, null);
    }

    /**
     *  Get a named parameter value.
     *  @param  name    The name of the parameter to look up.
     *  @return A reference to the class of the named parameter, or
     *          <code>null</code> if there is a problem loading the class.
     *  @since  Version 0.1 2005-07-12
     */
    public final Class getClassParameter(final String name) {

        return propertySet.getClass(name, null);
    }

    /**
     *  Get a named parameter value.
     *  @param  name    The name of the parameter to look up.
     *  @return The boolean value of named parameter, or <code>false</code> if
     *          not found.
     *  @since  Version 0.1 2005-07-12
     */
    public final boolean getBooleanParameter(final String name) {

        return propertySet.getBoolean(name, false);
    }

    /**
     *  Get the default store directory.
     *  @return A reference to the default output directory.
     *  @since  Version 0.2 2005-10-14
     */
    protected final File getDefaultStoreDirectory() {

        JSpiderConfiguration config = ConfigurationFactory.getConfiguration();

        return config.getDefaultOutputFolder();
    }

}
