package com.mkdoc.query;

/*
    Created:    2005-07-05
    Issued:     2005-07-06
    Modified:   2005-07-28

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.schema.ApplicationProfile;

import java.util.List;

/**
 *  A builder for query types.
 *  @version    0.4 2005-07-28
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public interface QueryBuilder {

    /**
     *  A single space character.
     *  @since  Version 0.2 2005-07-26
     */
    String SPACE = " ";

    /**
     *  A comma separator.
     *  @since  Version 0.2 2005-07-26
     */
    String APPEND_COMMA = ", ";

    /**
     *  A <code>SELECT</code> query type.
     *  @since  Version 0.2 2005-07-26
     */
    String SELECT = "SELECT";

    /**
     *  A <code>CONSTRUCT</code> query type.
     *  @since  Version 0.2 2005-07-26
     */
    String CONSTRUCT = "CONSTRUCT";

    /**
     *  A <code>DISTINCT</code> keyword.
     *  @since  Version 0.2 2005-07-26
     */
    String DISTINCT = " DISTINCT";

    /**
     *  A <code>FROM</code> keyword.
     *  @since  Version 0.2 2005-07-26
     */
    String FROM = " FROM ";

    /**
     *  An <code>AND</code> keyword.
     *  @since  Version 0.2 2005-07-26
     */
    String APPEND_AND = " AND ";

    /**
     *  An <code>OR</code> keyword.
     *  @since  Version 0.2 2005-07-26
     */
    String APPEND_OR = " OR ";

    /**
     *  A <code>WHERE</code> keyword.
     *  @since  Version 0.2 2005-07-26
     */
    String WHERE = " WHERE ";

    /**
     *  A <code>USING NAMESPACE</code> declaration.
     *  @since  Version 0.2 2005-07-26
     */
    String USING = " USING NAMESPACE ";

    /**
     *  An SeRQL &quot;LIKE&quot; keyword.
     *  @since  Version 0.2 2005-07-26
     */
    String LIKE = " LIKE ";

    /**
     *  An SeRQL &quot;NOT LIKE&quot; keyword.
     *  @since  Version 0.2 2005-07-26
     */
    String NOT_LIKE = " NOT LIKE ";

    /**
     *  A double quote character separator.
     *  @since  Version 0.1 2005-07-05
     */
    String QUOTE = "\"";

    /**
     *  Query delimiters.
     *  @since  Version 0.1 2005-07-05
     */
    String DELIMITERS = QUOTE + " \t\n\r\f";

    /**
     *  Set the application profile to use for interpreting queries.
     *  @param  profile The application profile to use to prepare the query.
     *  @since  Version 0.1 2005-07-05
     */
    void setApplicationProfile(final ApplicationProfile profile);

    /**
     *  Get query terms from a string input.
     *  @param  query   The contents of a single metadata query field, which
     *          may include multiple search terms separated by delimiters.
     *  @return A series of query terms extracted from the query field input.
     *  @since  Version 0.1 2005-07-05
     */
    List getQueryTerms(final String query);

    /**
     *  Specify whether to de-duplicate results.
     *  @param  distinct    Whether to de-duplicate the results.
     *  @since  Version 0.1 2005-07-05
     */
    void setDistinct(final boolean distinct);

    /**
     *  Parse the query source and get a <code>Query</code> object.
     *  @return A query based on the input source.
     *  @since  Version 0.1 2005-07-05
     */
    Query getQuery();

}
