package com.mkdoc.query;

/*
    Created:    2005-08-02
    Issued:     2005-08-04
    Modified:   2005-08-04

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

/**
 *  An output context for a query
 *  @version    0.2 2005-08-04
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public interface QueryContext {

    /**
     *  The default number of results per page.
     *  @since  Version 0.2 2005-08-04
     */
    int LIMIT = 10;

    /**
     *  The text output type.
     *  @since  Version 0.1 2005-08-02
     */
    String TEXT = "text";

    /**
     *  The XHTML output type.
     *  @since  Version 0.1 2005-08-02
     */
    String HTML = "html";

    /**
     *  The RSS output type.
     *  @since  Version 0.1 2005-08-02
     */
    String RSS = "rss";

    /**
     *  Get the requested page number for any results.
     *  @return The page number for any results
     *  @since  Version 0.1 2005-08-02
     */
    int getPageNumber();

    /**
     *  Get the maximum number of results to display per page.
     *  @return The maximum number of results to display per page.
     *  @since  Version 0.1 2005-08-02
     */
    int getResultsPerPage();

    /**
     *  Get the requested output format for the result.
     *  @return The output type for the result.
     *  @since  Version 0.1 2005-08-02
     */
    String getOutputType();

}
