package com.mkdoc.sax;

/*
    Created:    2005-02-15
    Issued:     2005-02-15
    Modified:   2005-11-01

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import org.openrdf.model.Graph;
import org.openrdf.model.URI;

import com.mkdoc.store.StoreManager;
import com.mkdoc.store.StoreException;

import org.xml.sax.SAXException;

/**
 *  Base class for content handlers that write to Sesame RDF repositories.
 *  @version    0.5 2005-11-01
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public abstract class AbstractStoreWriter
              extends AbstractRdfContentHandler {

    /**
     *  A store manager reference.
     *  @since  Version 0.4 2005-05-31
     */
    protected StoreManager manager;

    /**
     *  The resource graph.
     *  @since  Version 0.1 2005-02-15
     */
    protected Graph graph;

    /**
     *  The subject of the RDF statement.
     *  @since  Version 0.1 2005-02-15
     */
    protected URI subjectUri;

    /**
     *  Set the subject of the RDF statement.
     *  @param  uri The URI of the subject, such as the URL
     *          of an (X)HTML document.
     *  @since  Version 0.1 2005-02-15
     */
    public final void setSubjectUri(final URI uri) {

        if (uri == null) {

            throw new IllegalArgumentException(
                        "Null URI subject not permitted.");
        }

        subjectUri = uri;
    }

    /**
     *  Get the current subject of the RDF statement.
     *  @return The URI subject of the RDF statement, which
     *          may be the URL of an (X)HTML document.
     *  @since  Version 0.1 2005-02-15
     */
    public final URI getSubjectUri() {

        return subjectUri;
    }

    /**
     *  Add the graph to the repository.
     *  @exception  SAXException    If there is an error
     *          adding the <code>Graph</code> to the
     *          repository.
     *  @since  Version 0.1 2005-02-15
     */
    public final void endDocument() throws SAXException {

        try {

            manager.addDocumentStatements(subjectUri, graph);
        }
        catch (StoreException se) {

            throw new SAXException("Problem adding graph to repository.",
                                   se);
        }
    }

}
