package com.mkdoc.schema;

/*
    Created:    2005-06-16
    Issued:     2005-06-16
    Modified:   2005-10-21

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import java.util.Locale;

/**
 *  A Dublin Core Metadata Element schema property.
 *  @version    0.6 2005-10-21
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class UKeGMSProperty extends AbstractSchemaProperty
                                                    implements SchemaProperty {

    /**
     *  The namespace prefix for the class.
     *  @since  Version 0.1 2005-06-16
     */
    private static final String NS_PREFIX = "egms";

    /**
     *  The namespace URI for the class.
     *  @since  Version 0.1 2005-06-16
     */
    private static final String NS_URI = "http://www.govtalk.gov.uk/terms/";

    /**
     *  The schema locale.
     *  @since  Version 0.1 2005-06-16
     */
    private static final Locale LOCALE = Locale.UK;

    /**
     *  Basic constructor for instances without encoding.
     *  @param  uri The resource URI.
     *  @param  label   The resource label.
     *  @param  name    The unique resource name.
     *  @since  Version 0.1 2005-06-15
     */
    public UKeGMSProperty(final String uri,
                          final String label,
                          final String name) {

        this(uri, label, name, false, false);
    }

    /**
     *  Construct a property with an optional encoding scheme.
     *  @param  uri The resource URI.
     *  @param  label   The resource label.
     *  @param  name    The unique resource name.
     *  @param  encoding    Whether the instance has an encoding scheme that
     *          may be applied to it.
     *  @since  Version 0.3 2005-09-14
     */
    public UKeGMSProperty(final String uri,
                          final String label,
                          final String name,
                          final boolean encoding) {

        this(uri, label, name, encoding, false);
    }

    /**
     *  Good citizen constructor.
     *  @param  uri The resource URI.
     *  @param  label   The resource label.
     *  @param  name    The unique resource name.
     *  @param  encoding    Whether the instance has an encoding scheme that
     *          may be applied to it.
     *  @param  uriEncoding Whether the instance may have a URI encoding
     *          scheme.
     *  @since  Version 0.4 2005-09-15
     */
    public UKeGMSProperty(final String uri,
                          final String label,
                          final String name,
                          final boolean encoding,
                          final boolean uriEncoding) {

        super();

        if ((uri == null) ||
            (label == null) ||
            (name == null)) {

            throw new IllegalArgumentException(
                        "Null arguments not permitted.");
        }
        else {
            this.uri = uri;
            this.label = label;
            this.name = name;
            this.encoding = encoding;

            if (encoding) {

                this.uriEncoding = uriEncoding;
            }
        }
    }

    /**
     *  Get the namespace prefix for the class.
     *  @return The namespace prefix for the class.
     *  @since  Version 0.1 2005-06-16
     */
    public final String getNamespacePrefix() {

        return NS_PREFIX;
    }

    /**
     *  Get the namespace URI for the class.
     *  @return The namespace prefix for the class.
     *  @since  Version 0.1 2005-06-16
     */
    public final String getNamespaceUri() {

        return NS_URI;
    }

    /**
     *  Check equivalance of properties.
     *  @param  other   The object to compare with this.
     *  @return <code>true</code> if the other object is equivalent to this.
     *  @since  Version 0.2 2005-06-30
     */
    public final boolean equals(final Object other) {

        return ((other != null) &&
                (other instanceof UKeGMSProperty) &&
                (other.hashCode() == hashCode()));
    }

    /**
     *  Get a distinct hash code value.
     *  @return A distinct hash code value for the property.
     *  @since  Version 0.2 2005-06-30
     */
    public final int hashCode() {

        return getUri().hashCode();
    }

    /**
     *  Get the locale of the property for case conversions, etc.
     *  @return The locale for the schema property.
     *  @since  Version 0.5 2005-10-14
     */
    public final Locale getLocale() {

        return LOCALE;
    }

}
