package com.mkdoc.servlet;

/*
    Created:    2005-01-20
    Issued:     2005-01-25
    Modified:   2005-07-26

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.util.ApplicationContext;

import javax.servlet.ServletContext;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;

/**
 *  An abstract implementation of servlet utilities.
 *  @version    0.4 2005-07-26
 *  @author     Philip Shaw
 */
public abstract class AbstractMKDocServlet extends HttpServlet {

    /**
     *  A null servlet request error message.
     *  @since  Version 0.3 2005-07-25
     */
    private static final String NULL_REQUEST =
    "Null servlet request not permitted.";

    /**
     *  The double quote character reference.
     *  @since  Version 0.2 2005-05-18
     */
    private static final int QUOTE = 34;

    /**
     *  The ampersand character reference.
     *  @since  Version 0.2 2005-05-18
     */
    private static final int AMPERSAND = 38;

    /**
     *  The less than character reference.
     *  @since  Version 0.2 2005-05-18
     */
    private static final int LESS = 60;

    /**
     *  The more than character reference.
     *  @since  Version 0.2 2005-05-18
     */
    private static final int MORE = 62;

    /**
     *  Protected default constructor.
     *  @since  Version 0.1 2005-01-20
     */
    protected AbstractMKDocServlet() {

        // Empty
    }

    /**
     *  Get the first parameter by a given name.
     *  @param  request The HTTP servlet request.
     *  @param  name    The name of the parameter value to get.
     *  @return The value of the first named parameter in the request or
     *          <code>null</code> if the parameter does not exist or is
     *          blank.
     *  @since  Version 0.1 2005-01-20
     */
    public static final String getFirstParam(final HttpServletRequest request,
                                             final String name) {

        if (request != null) {

            if (name != null) {

                String[] params = request.getParameterValues(name);

                if (params != null) {

                    String param = params[0].trim();

                    if (!param.equals("")) {

                        return param;
                    }
                    // Fall through
                }
                // Fall through

                return null;
            }
            else {

                throw new IllegalArgumentException(NULL_REQUEST);
            }
        }
        else {

            throw new IllegalArgumentException(NULL_REQUEST);
        }
    }

    /**
     *  Filter a string for potentially malicious markup.
     *  @param  input   A servlet parameter to filter.
     *  @return The input string with potentially malicious
     *          markup converted to HTML entities.
     *  @since  Version 0.2 2005-05-18
     */
    public static final String filter(final String input) {

        char[] charArray = input.toCharArray();


        int chars = charArray.length;

        StringBuffer buffer = new StringBuffer(chars);

        for (int i = 0; i < chars; i++) {

            switch (charArray[i]) {

                case QUOTE:
                buffer.append("&quot;");
                break;

                case AMPERSAND:
                buffer.append("&amp;");
                break;

                case LESS:
                buffer.append("&lt;");
                break;

                case MORE:
                buffer.append("&gt;");
                break;

                default:
                buffer.append(charArray[i]);
            }
        }

        return buffer.toString();
    }

    /**
     *  Get an application context for a servlet.
     *  @param  context The servlet context for an application.
     *  @return A new application context.
     *  @since  Version 0.3 2005-07-19
     */
    public static final ApplicationContext getApplicationContext(
                                                final ServletContext context) {

        if (context != null) {

            return new ServletApplicationContext(context);
        }
        else {

            throw new IllegalArgumentException(
                        "Null servlet context not permitted.");
        }
    }

}
