package com.mkdoc.sesame;

/*
    Created:    2005-01-26
    Issued:     2005-01-26
    Modified:   2005-07-22

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import org.openrdf.model.Value;

import org.openrdf.sesame.query.QueryResultsTable;

import java.io.IOException;

import javax.servlet.ServletOutputStream;

/**
 *  Renders Sesame query results to plain text.
 *  @version    0.2 2005-02-02
 *  @author     Philip Shaw <phil@mkdoc.com>
 *  @deprecated Use com.mkdoc.query.TextResultRenderer
 */
public class TextResultsRenderer implements ResultsRenderer {

    /**
     *  The text content type.
     *  @since  Version 0.1 2005-01-26
     */
    public static final String CONTENT_TYPE = "text/plain";

    /**
     *  Render a query results table to a servlet output stream.
     *  @param  outputStream    The output stream to which to write the
     *          results.
     *  @param  table   The query results table to render.
     *  @exception  IOException If there is a problem writing results to the
     *          output stream.
     *  @since  Version 0.1 2005-01-26
     */
    public final void renderResults(final ServletOutputStream outputStream,
                                    final QueryResultsTable table)
        throws IOException {

        if (outputStream != null) {

            if (table != null) {

                int rows = table.getRowCount();

                int cols = table.getColumnCount();

                if (rows > 0) {

                    outputStream.println("Query results");

                    for (int row = 0; row < rows; row++) {

                        for (int col = 0; col < cols; col++) {

                            Value value = table.getValue(row, col);

                            if (value != null) {

                                outputStream.print(value.toString());
                            }
                            else {

                                outputStream.print("null");
                            }

                            outputStream.print("\t");
                        }

                        outputStream.println();
                    }
                }
                else {

                    outputStream.println("No results");
                }
            }
            else {

                throw new IllegalArgumentException(
                            "Null results table not permitted.");
            }
        }
        else {

            throw new IllegalArgumentException(
                        "Null output stream not permitted.");
        }
    }

    /**
     *  Render a query results table to a string.
     *  @param  table   The query results table to render.
     *  @return A text formatted tabular layout of the query results.
     *  @since  Version 0.1 2005-01-26
     */
    public final String renderResults(final QueryResultsTable table) {

        StringBuffer buffer = new StringBuffer();

        if (table != null) {

            int rows = table.getRowCount();

            int cols = table.getColumnCount();

            if (rows > 0) {

                buffer.append("Query results\n");

                for (int row = 0; row < rows; row++) {

                    for (int col = 0; col < cols; col++) {

                        Value value = table.getValue(row, col);

                        if (value != null) {

                            buffer.append(value.toString());
                        }
                        else {

                            buffer.append("null");
                        }

                        buffer.append("\t");
                    }

                    buffer.append("\r\n");
                }
            }
            else {

                buffer.append("No results");
            }

            return buffer.toString();
        }
        else {

            throw new IllegalArgumentException(
                        "Null results table not permitted.");
        }
    }

    /**
     *  Get the content type for the renderer.
     *  @return The MIME type <code>text/plain</code>.
     *  @since  Version 0.1 2005-01-26
     */
    public final String getContentType() {

        return CONTENT_TYPE;
    }

}
