package com.mkdoc.sesame;

/*
    Created:    2005-02-02
    Issued:     2005-02-02
    Modified:   2005-07-22

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import org.openrdf.model.Value;

import org.openrdf.sesame.query.QueryResultsTable;

import java.io.IOException;

import javax.servlet.ServletOutputStream;

/**
 *  Renders Sesame query results to XHTML.
 *  @version    0.1 2005-02-02
 *  @author     Philip Shaw <phil@mkdoc.com>
 *  @deprecated Use com.mkdoc.query.XhtmlResultRenderer
 */
public class XhtmlResultsRenderer implements ResultsRenderer {

    /**
     *  The text content type.
     *  @since  Version 0.1 2005-02-02
     */
    public static final String CONTENT_TYPE = "text/html";

    /**
     *  An XHTML document header.
     *  @since  Version 0.1 2005-02-02
     */
    public static final String HEADER =
    "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" " +
    "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n" +
    "<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en-GB\" " +
    "dir=\"ltr\">\n" +
    "  <head  profile=\"http://dublincore.org/documents/dcq-html/\">\n" +
    "    <title>\n" +
    "      MKSearch: Query results\n" +
    "    </title>\n" +
    "  </head>\n" +
    "  <body>\n";

    /**
     *  An XHTML document footer.
     *  @since  Version 0.1 2005-02-02
     */
    public static final String FOOTER =
    "   </body>\n" +
    "</html>\n";

    /**
     *  Render a query results table to a servlet output stream.
     *  @param  outputStream    The output stream to which to write the
     *          results.
     *  @param  table   The query results table to render.
     *  @exception  IOException If there is a problem writing results to the
     *          output stream.
     *  @since  Version 0.1 2005-02-02
     */
    public final void renderResults(final ServletOutputStream outputStream,
                                    final QueryResultsTable table)
        throws IOException {

        if (outputStream != null) {

            if (table != null) {

                outputStream.print(HEADER);

                int rows = table.getRowCount();

                int cols = table.getColumnCount();

                if (rows > 0) {

                    outputStream.println("<h1>Query results</h1>");

                    outputStream.println("<dl>");

                    for (int row = 0; row < rows; row++) {

                        for (int col = 0; col < cols; col++) {

                            Value value = table.getValue(row, col);

                            if (col == 0) {

                                outputStream.println("<dt>");

                                if (value != null) {

                                    outputStream.print("<a href=\"");
                                    outputStream.print(value.toString());
                                    outputStream.print("\">");
                                    outputStream.print(value.toString());
                                    outputStream.println("</a>");
                                }
                                else {

                                    outputStream.println("<em>null</em>");
                                }

                                outputStream.println("</dt>");
                                outputStream.println("<dd>");
                           }
                           else {

                                if (value != null) {

                                    outputStream.println(value.toString());
                                }
                                else {

                                    outputStream.println("<em>null</em>");
                                }
                           }
                        }

                        outputStream.println("</dd>");
                    }
                    outputStream.println("</dl>");

                }
                else {

                    outputStream.println("<h1>");
                    outputStream.println("  No results");
                    outputStream.println("</h1>");
                }

                outputStream.print(FOOTER);
            }
            else {

                throw new IllegalArgumentException(
                            "Null results table not permitted.");
            }
        }
        else {

            throw new IllegalArgumentException(
                        "Null output stream not permitted.");
        }
    }

    /**
     *  Render a query results table to a string.
     *  @param  table   The query results table to render.
     *  @return A text formatted tabular layout of the query results.
     *  @since  Version 0.1 2005-02-02
     */
    public final String renderResults(final QueryResultsTable table) {

        StringBuffer buffer = new StringBuffer();

        if (table != null) {

            buffer.append(HEADER);

            int rows = table.getRowCount();

            int cols = table.getColumnCount();

            if (rows > 0) {

                buffer.append("<h1>\n");
                buffer.append("  Query results\n");
                buffer.append("</h1>\n");

                buffer.append("<dl>\n");

                for (int row = 0; row < rows; row++) {

                    for (int col = 0; col < cols; col++) {

                        Value value = table.getValue(row, col);

                        if (col == 0) {

                            buffer.append("<dt>\n");

                            if (value != null) {

                                buffer.append("<a href=\"");
                                buffer.append(value.toString());
                                buffer.append("\">");
                                buffer.append(value.toString());
                                buffer.append("</a>");
                            }
                            else {

                                buffer.append("<em>null</em>\n");
                            }

                            buffer.append("</dt>\n");
                            buffer.append("<dd>\n");
                       }
                       else {

                            if (value != null) {

                                buffer.append(value.toString());
                            }
                            else {

                                buffer.append("<em>null</em>\n");
                            }
                       }
                    }

                    buffer.append("</dd>\n");
                }
                buffer.append("</dl>\n");
            }
            else {
                buffer.append("<h1>\n");
                buffer.append("  No results\n");
                buffer.append("</h1>\n");
            }

            buffer.append(FOOTER);

            return buffer.toString();
        }
        else {

            throw new IllegalArgumentException(
                        "Null results table not permitted.");
        }
    }

    /**
     *  Get the content type for the renderer.
     *  @return The MIME type <code>text/html</code>.
     *  @since  Version 0.1 2005-02-02
     */
    public final String getContentType() {

        return CONTENT_TYPE;
    }

}
