package com.mkdoc.store;

/*
    Created:    2005-06-06
    Issued:     2005-
    Modified:   2005-10-26

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import org.openrdf.model.Statement;

import org.openrdf.sesame.admin.AdminListener;

import java.util.List;
import java.util.Vector;

/**
 *  Store error statements for post-processing, draft.
 *  @version    0.1 2005-06-06
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class ImportListener implements AdminListener {

    /**
     *  A list of notified statements.
     *  @since  Version 0.1 2005-06-06
     */
    protected List notices = new Vector();

    /**
     *  A list of statements with warnings.
     *  @since  Version 0.1 2005-06-06
     */
    protected List warnings = new Vector();

    /**
     *  A list of error statements.
     *  @since  Version 0.1 2005-06-06
     */
    protected List errors = new Vector();

    /**
     *  Report the start of the import.
     *  @since  Version 0.1 2005-06-06
     */
    public final void transactionStart() {

        // Empty
    }

    /**
     *  Report the end of the import.
     *  @since  Version 0.1 2005-06-06
     */
    public final void transactionEnd() {

        // Empty
    }

    /**
     *  Report current status.
     *  @param  message A status message reported during the import.
     *  @param  lineNo  The line number to which the status report relates.
     *  @param  columnNo    The column number to which the status report
     *          relates.
     *  @since  Version 0.1 2005-06-06
     */
    public final void status(final String message,
                             final int lineNo,
                             final int columnNo) {

        // Empty
    }

    /**
     *  Report a special notification.
     *  @param  message A special notification message reported during the
     *          import.
     *  @param  lineNo  The line number to which the notification relates.
     *  @param  columnNo    The column number to which the notification
     *          relates.
     *  @param  statement   An RDF statement associated with the notification.
     *  @since  Version 0.1 2005-06-06
     */
    public final void notification(final String message,
                                   final int lineNo,
                                   final int columnNo,
                                   final Statement statement) {

        notices.add(statement);
    }

    /**
     *  Report a warning.
     *  @param  message A warning message reported during the import.
     *  @param  lineNo  The line number to which the warning relates.
     *  @param  columnNo    The column number to which the warning relates.
     *  @param  statement   An RDF statement associated with the notification.
     *  @since  Version 0.1 2005-06-06
     */
    public final void warning(final String message,
                              final int lineNo,
                              final int columnNo,
                              final Statement statement) {

        warnings.add(statement);
    }

    /**
     *  Report an error.
     *  @param  message An error message reported during the import.
     *  @param  lineNo  The line number to which the error report relates.
     *  @param  columnNo    The column number to which the error report
     *          relates.
     *  @param  statement   An RDF statement associated with the notification.
     *  @since  Version 0.1 2005-06-06
     */
    public final void error(final String message,
                            final int lineNo,
                            final int columnNo,
                            final Statement statement) {

        errors.add(statement);
    }

}

