package com.mkdoc.store;

/*
    Created:    2005-03-31
    Issued:     2005-03-31
    Modified:   2005-11-01

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import org.openrdf.model.Graph;
import org.openrdf.model.URI;

import com.mkdoc.query.Query;
import com.mkdoc.query.QueryResult;

import java.io.InputStream;

import java.net.URL;

/**
 *  A type that implements all manager interfaces.
 *  @version    0.2 2005-11-01
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public interface StoreManager extends Manager {

    /**
     *  The repository path configuration key.
     *  @since  Version 0.2 2005-11-01
     */
    String REPOSITORY = "repository";

    /**
     *  Add statements about a document by subject URI.
     *  @param  subjectUri  The URI of the subject document to add.
     *  @param  graph   The RDF graph of statements about this document.
     *  @exception  StoreException  If an error occurs with the triple store.
     *  @since  Version 0.2 2005-11-01
     */
    void addDocumentStatements(final URI subjectUri,
                               final Graph graph) throws StoreException;

    /**
     *  Add an RDF data stream to the store.
     *  @param  inStream    The data stream to add to the store.
     *  @param  baseUri The URL base of the source.
     *  @exception  StoreException  If there is a problem importing the data to
     *          the repository.
     *  @since  Version 0.2 2005-11-01
     */
    void addXmlRdfStream(final InputStream inStream,
                         final URL baseUri) throws StoreException;

    /**
     *  Execute a query against the data store.
     *  @param  query   The query to apply to the store.
     *  @return A result set that fulfils the submitted query.
     *  @since  Version 0.2 2005-11-01
     */
    QueryResult executeQuery(final Query query);

}
