package com.mkdoc.tag;

/*
    Created:    2005-05-18
    Issued:     2005-05-18
    Modified:   2005-10-14

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.schema.ApplicationProfile;
import com.mkdoc.schema.DublinCoreProfile;
import com.mkdoc.schema.Schema;
import com.mkdoc.schema.SchemaProperty;

import com.mkdoc.servlet.AbstractMKDocServlet;

import java.io.IOException;

import java.util.Collection;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Vector;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;

/**
 *  A JSP tag that dynamically modifies a search form with advanced fields.
 *  @version    0.9 2005-10-13
 *  @author     Philip Shaw <phil@mkdoc.com>
 *  @TODO   Make the application profile configurable through the tag library
 *          descriptor and a new init method.
 */
public class QueryBuilderTag extends AbstractXhtmlTag {

    /**
     *  The default results per page.
     *  @since  Version 0.8 2005-09-12
     */
    private static final int LIMIT = 10;

    /**
     *  The maximum results per page.
     *  @since  Version 0.8 2005-09-12
     */
    private static final int LIMIT_MAX = 100;

    /**
     *  The double increment factor.
     *  @since  Version 0.8 2005-09-12
     */
    private static final int DOUBLE = 2;

    /**
     *  Start a type selection radio box input.
     *  @since  Version 0.4 2005-07-04
     */
    private static final String START_TYPE =
    "<input type=\"radio\" name=\"type\" ";

    /**
     *  Start a select item with opening value attribute.
     *  @since  Version 0.4 2005-07-04
     */
    private static final String START_OPTION = "<option value=\"";

    /**
     *  Start a <code>th</code> element, top aligned.
     *  @since  Version 0.8 2005-09-12
     */
    private static final String START_TH = "<th valign=\"top\">";

    /**
     *  A null argument error message.
     *  @since  Version 0.4 2005-07-04
     */
    private static final String NULL_ARGS = "Null arguments not permitted.";

    /**
     *  A form field visibility flag.
     *  @since  Version 0.1 2005-05-18
     */
    private static final boolean VISIBLE = true;

    /**
     *  A form field visibility flag.
     *  @since  Version 0.1 2005-05-18
     */
    private static final boolean HIDDEN = false;

    /**
     *  An application profile.
     *  @since  Version 0.2 2005-06-17
     */
    private final ApplicationProfile profile = new DublinCoreProfile();

    /**
     *  The query URL attribute.
     *  @since  Version 0.8 2005-09-12
     */
    private String queryUrl;

    /**
     *  The builder URL attribute.
     *  @since  Version 0.8 2005-09-12
     */
    private String builderUrl;

    /**
     *  Make an open form tag with encoded URL.
     *  @return The skip body signal.
     *  @exception  JspException    If there is a problem writing to the
     *          servlet output stream.
     *  @since  Version 0.1 2005-05-18
     */
    public final int doStartTag() throws JspException {

        try {

            HttpServletResponse response = null;

            response = (HttpServletResponse) pageContext.getResponse();


            HttpServletRequest request = null;

            request = (HttpServletRequest) pageContext.getRequest();


            JspWriter out = pageContext.getOut();


            printQueryForm(request, out);

            printBuilderForm(request, response, out);

        }
        catch (Exception e) {

            throw new JspException("Error in query builder start tag.",
                                   e);
        }

        return SKIP_BODY;
    }

    /**
     *  Print the query form to the JSP output.
     *  @param  request The servlet request object.
     *  @param  out The JSP output stream.
     *  @exception  IOException If there is a problem writing to the JSP output
     *          stream.
     *  @since  Version 0.3 2005-06-29
     */
    protected final void printQueryForm(final HttpServletRequest request,
                                        final JspWriter out)
        throws IOException {

        if ((request == null) ||
            (out == null)) {

            throw new IllegalArgumentException(NULL_ARGS);
        }

        out.print("<form action=\"");
        out.print(getQueryUrl());
        out.print("\"");
        out.println(" method=\"get\" class=\"QueryForm\">");

        out.println("<table summary=\"Metadata query input\" border=\"0\">");
        out.println("<col width=\"25%\" />");
        out.println("<col width=\"65%\" />");
        out.println("<col width=\"10%\" />");
        //out.println("<caption>");
        //out.println("Enter a query and submit");
        //out.println("</caption>");

        addQueryFields(request, out);

        out.println(OPEN_TR);
        out.println(START_TH);
        out.println("<label for=\"type-selector\">");
        out.println("Results:");
        out.println(SHUT_LABEL);
        out.println(SHUT_TH);
        out.println(OPEN_TD);
        out.println("<fieldset id=\"type-selector\">");
        out.print(START_TYPE);
        out.print("id=\"type-selector-html\" value=\"html\" ");
        out.print("checked=\"checked\" />");
        out.println("<label for=\"type-selector-html\">");
        out.println("<strong>HTML</strong>");
        out.println("</label><br />");
        out.print(START_TYPE);
        out.print("id=\"type-selector-rss\" value=\"rss\" />");
        out.println("<label for=\"type-selector-rss\">");
        out.println("News Feed (RSS)");
        out.print("</label>");
        //outlprintln("<br />");
        //out.print(START_TYPE);
        //out.print("id=\"type-selector-rdf\" value=\"rdf\" />");
        //out.println("<label for=\"type-selector-rdf\">");
        //out.println("RDF Metadata");
        //out.println(SHUT_LABEL);
        //out.println("</fieldset>");
        out.println(SHUT_TD);
        out.println(SHUT_TR);

        out.println(OPEN_TR);
        out.println(START_TH);
        out.println("<label for=\"limit-selector\">");
        out.println("Limit to:");
        out.println(SHUT_LABEL);
        out.println(SHUT_TH);
        out.println(OPEN_TD);


        out.println("<select name=\"limit\" id=\"limit-selector\">");

        String limit = AbstractMKDocServlet.getFirstParam(request, "limit");

        int items = 0;

        try {

            items = Integer.parseInt(limit);
        }
        catch (NumberFormatException nfe) {

            items = LIMIT;
        }

        for (int i = LIMIT; i < LIMIT_MAX; i *= DOUBLE) {

            if (i == items) {

                out.println(START_OPTION +
                            String.valueOf(i) +
                            "\" selected=\"selected\">" +
                            String.valueOf(i) +
                            "</option>");
            }
            else {

                out.println(START_OPTION +
                            String.valueOf(i) +
                            "\">" +
                            String.valueOf(i) +
                            "</option>");
            }
        }

        out.println("</select> results per page");
        out.println(SHUT_TD);
        out.println(SHUT_TR);

        out.println(OPEN_TR);
        out.println(START_TH);
        out.println("<label for=\"echo-check\">");
        out.println("Echo query:");
        out.println(SHUT_LABEL);
        out.println(SHUT_TH);
        out.println(OPEN_TD);
        out.println("<input type=\"checkbox\" name=\"echo\" ");
        out.print("id=\"echo-check\" value=\"true\" />");
        out.println("<label for=\"echo-check\">");
        out.println("Yes");
        out.println("</label>");
        out.println(SHUT_TD);
        out.println(SHUT_TR);

        out.println("</table>");
        out.println("</form>");
    }

    /**
     *  Print the builder form to the JSP output.
     *  @param  request The servlet request object.
     *  @param  response    The servlet response object.
     *  @param  out The JSP output stream.
     *  @exception  IOException If there is a problem writing to the JSP output
     *          stream.
     *  @since  Version 0.3 2005-06-29
     */
    protected final void printBuilderForm(final HttpServletRequest request,
                                          final HttpServletResponse response,
                                          final JspWriter out)
        throws IOException {

        if ((request == null) ||
            (response == null) ||
            (out == null)) {

            throw new IllegalArgumentException(NULL_ARGS);
        }

        out.print("<form action=\"");
        out.print(getBuilderUrl());
        out.print("\"");
        out.println(" method=\"post\" class=\"BuilderForm\">");

        out.println("<table summary=\"Metadata query input\" border=\"0\">");
        out.println("<col width=\"25%\" />");
        out.println("<col width=\"75%\" />");
        out.println(OPEN_TR);
        out.println(OPEN_TH);

        List selected = addBuilderFields(request, out);

        out.println("<label for=\"add-field\">");
        out.println("Add&nbsp;field:");
        out.println(SHUT_LABEL);
        out.println(SHUT_TH);
        out.println(OPEN_TD);
        out.println("<select name=\"add-field\" id=\"add-field\">");

        addSelectorOptions(selected, out);

        String resetUrl = response.encodeURL(request.getContextPath() +
                                             "/index.jsp");

        out.println("</select>");
        out.println("<input type=\"submit\" value=\"Add\" />");
        out.println("&nbsp;<a href=\"" + resetUrl + "\">Reset</a>");
        out.println(SHUT_TD);
        out.println(SHUT_TR);
        out.println("</table>");
        out.println("</form>");
    }

    /**
     *  Generate an option list of field options for a select element.
     *  @param  selected    A list of fields that are already selected.
     *  @param  out The JSP output stream.
     *  @exception  IOException If there is a problem writing to the output
     *          stream.
     *  @since  Version 0.1 2005-05-18
     */
    private void addSelectorOptions(final List selected,
                                    final JspWriter out)
        throws IOException {

        Map schemaMap = profile.getSchemaMap();

        Collection schemas = schemaMap.values();

        Iterator iterator = schemas.iterator();

        Schema schema = null;

        while (iterator.hasNext()) {

            schema = (Schema) iterator.next();

            out.print("<optgroup label=\"");
            out.print(schema.getName());
            out.println(END_ATTR_TAG);

            addOptiongroupOptions(schema, selected, out);

            out.println("</optgroup>");
        }
    }

    /**
     *  Generate an option group list of field options for a select element.
     *  @param  schema  A schema instance from which to list get query options
     *  @param  selected    A list of fields that are already selected.
     *  @param  out The JSP output stream.
     *  @exception  IOException If there is a problem writing to the output
     *          stream.
     *  @since  Version 0.1 2005-05-18
     */
    private void addOptiongroupOptions(final Schema schema,
                                       final List selected,
                                       final JspWriter out)
        throws IOException {

        Collection predicates = schema.getPredicates();

        Iterator iterator = predicates.iterator();

        SchemaProperty property = null;

        while (iterator.hasNext()) {

            property = (SchemaProperty) iterator.next();

            if (!selected.contains(property)) {

                out.print(START_OPTION);
                out.print(property.getParameterName());
                out.println(END_ATTR_TAG);
                out.println(property.getLabel());
                out.println("</option>");
            }
        }
    }

    /**
     *  Output visible query form fields.
     *  @param  request The JSP request object.
     *  @return A list of fields already added to the query form.
     *  @param  out The JSP output stream.
     *  @exception  IOException If there is a problem writing to the output
     *          stream.
     *  @since  Version 0.1 2005-05-18
     */
    private List addQueryFields(final HttpServletRequest request,
                                final JspWriter out)
        throws IOException {

        return addFormFields(request, out, VISIBLE);
    }

    /**
     *  Output hidden builder form fields.
     *  @param  request The JSP request object.
     *  @param  out The JSP output stream.
     *  @return A list of fields added to the builder form.
     *  @exception  IOException If there is a problem writing to the output
     *          stream.
     *  @since  Version 0.1 2005-05-18
     */
    private List addBuilderFields(final HttpServletRequest request,
                                  final JspWriter out)
        throws IOException {

        return addFormFields(request, out, HIDDEN);
    }

    /**
     *  Output form fields.
     *  <p>
     *    Merges multiple parameters by the same name into a space separated
     *    list of values.
     *  </p>
     *  @param  request The JSP request object.
     *  @param  out The JSP output stream.
     *  @param  visible Whether the form field is visible or hidden.
     *  @return A list of fields added to the form.
     *  @exception  IOException If there is a problem writing to the output
     *          stream.
     *  @since  Version 0.1 2005-05-18
     */
    private List addFormFields(final HttpServletRequest request,
                               final JspWriter out,
                               final boolean visible)
        throws IOException {


        List selected = new Vector();

        printPrimaryField(request,
                          out,
                          selected,
                          visible);

        printSecondaryFields(request,
                             out,
                             selected,
                             visible);

        printAddedField(request,
                        out,
                        selected,
                        visible);

        return selected;
    }

    /**
     *  Print the primary search or build field.
     *  @param  request The servlet request object.
     *  @param  out The JSP output stream.
     *  @param  selected    The list of selected parameter names.
     *  @param  visible Whether this is part of the visible query form or
     *          hidden builder form.
     *  @exception  IOException If there is a problem writing to the JSP output
     *          stream.
     *  @since  Version 0.3 2005-06-29
     */
    protected final void printPrimaryField(final HttpServletRequest request,
                                           final JspWriter out,
                                           final List selected,
                                           final boolean visible)
        throws IOException {

        if ((request == null) ||
            (out == null) ||
            (selected == null)) {

            throw new IllegalArgumentException(NULL_ARGS);
        }

        SchemaProperty property = profile.getPrimarySearchProperty();

        if (visible) {

            selected.add(property);

            addFormField(request, property, out, visible, visible);
        }
        // Else no need to create hidden field, always output
    }

    /**
     *  Print the secondary search or build fields.
     *  @param  request The servlet request object.
     *  @param  out The JSP output stream.
     *  @param  selected    The list of selected parameter names.
     *  @param  visible Whether this is part of the visible query form or
     *          hidden builder form.
     *  @exception  IOException If there is a problem writing to the JSP output
     *          stream.
     *  @since  Version 0.3 2005-06-29
     */
    protected final void printSecondaryFields(final HttpServletRequest request,
                                              final JspWriter out,
                                              final List selected,
                                              final boolean visible)
        throws IOException {

        if ((request == null) ||
            (out == null) ||
            (selected == null)) {

            throw new IllegalArgumentException(NULL_ARGS);
        }

        Enumeration enumerator = request.getParameterNames();

        String name = null;

        SchemaProperty property = null;

        while (enumerator.hasMoreElements()) {

            name = (String) enumerator.nextElement();

            property = profile.getPredicateProperty(name);

            if ((property != null) &&
                (!selected.contains(property))) {

                selected.add(property);

                addFormField(request, property, out, visible, false);
            }
        }
    }

    /**
     *  Print any additional search or build field.
     *  @param  request The servlet request object.
     *  @param  out The JSP output stream.
     *  @param  selected    The list of selected parameter names.
     *  @param  visible Whether this is part of the visible query form or
     *          hidden builder form.
     *  @exception  IOException If there is a problem writing to the JSP output
     *          stream.
     *  @since  Version 0.3 2005-06-29
     */
    protected final void printAddedField(final HttpServletRequest request,
                                         final JspWriter out,
                                         final List selected,
                                         final boolean visible)
        throws IOException {

        if ((request == null) ||
            (out == null) ||
            (selected == null)) {

            throw new IllegalArgumentException(NULL_ARGS);
        }

        String newName = AbstractMKDocServlet.getFirstParam(request,
                                                            "add-field");

        SchemaProperty property = null;

        if (newName != null) {

            property = profile.getPredicateProperty(newName);

            if ((property != null) &&
                (!selected.contains(property))) {

                selected.add(property);

                addFormField(request, property, out, visible, false);
            }
        }
    }

    /**
     *  Add a single form field.
     *  @param  request The JSP request object.
     *  @param  property    An individual schema property to use for the field.
     *  @param  out The JSP output stream.
     *  @param  visible Whether the form field should be visible or hidden.
     *  @param  submit  Whether to add a submit button to the form field.
     *  @exception  IOException If there is a problem writing to the output
     *          stream.
     *  @since  Version 0.1 2005-05-18
     */
    private void addFormField(final HttpServletRequest request,
                              final SchemaProperty property,
                              final JspWriter out,
                              final boolean visible,
                              final boolean submit)
        throws IOException {

        if (visible) {

            out.println(OPEN_TR);
            out.println(OPEN_TH);

              out.print("<label for=\"");
              out.print(property.getNameVariable());
            out.println(END_ATTR_TAG);

            String label = property.getLabel();

              out.print(label);
            out.println(":");

            out.println(SHUT_LABEL);
            out.println(SHUT_TH);
            out.println(OPEN_TD);

              out.print("<input type=\"text\" size=\"50\" alt=\"Enter a ");
              out.print(label.toLowerCase(property.getLocale()));
              out.print(" query\" ");
        }
        else {

              out.print("<input type=\"hidden\" ");
        }

        String values = getParameterValues(request,
                                           property.getParameterName());

        out.print("name=\"");
        out.print(property.getParameterName());
        out.print("\" ");

        if (visible) {

            out.print("id=\"");
            out.print(property.getNameVariable());
            out.print("\" ");
        }

        out.print("value=\"");
        out.print(values.trim());
        out.println("\" />");

        if (visible) {

            out.println(SHUT_TD);

            if (submit) {

                out.println(OPEN_TD);
                out.println("<input type=\"submit\" class=\"submit\" " +
                            "value=\"Search\" />");
                out.println(SHUT_TD);
            }
            out.println(SHUT_TR);
        }
    }

    /**
     *  Get a space separated list of parameter values by name.
     *  @param  request The JSP request object.
     *  @param  name    The parameter name.
     *  @return A space separated list of parameter names, or the empty string.
     */
    public final String getParameterValues(final HttpServletRequest request,
                                           final String name) {

        if ((request == null) ||
            (name == null)) {

            throw new IllegalArgumentException(
                        "Null parameters not permitted.");
        }
        String[] values = request.getParameterValues(name);

        if (values != null) {

            int items = values.length;

            StringBuffer buffer = new StringBuffer();

            String value = null;

            boolean first = true;

            for (int i = 0; i < items; i++) {

                value = values[i].trim();

                if (value.length() > 0) {

                    if (first) {

                        first = false;
                    }
                    else {

                        buffer.append(" ");
                    }

                    buffer.append(AbstractMKDocServlet.filter(values[i]));
                }
            }

            return buffer.toString();
        }
        // Drop through

        return "";
    }

    /**
     *  Encode the query URL attribute.
     *  @param  url A query URL for the form, relative to the server root.
     *  @since  Version 0.1 2005-05-18
     */
    public final void setQueryUrl(final String url) {

        if (url == null) {

            throw new IllegalArgumentException(
                        "Null action not permitted.");
        }
        else {

            HttpServletRequest request = null;

            HttpServletResponse response = null;

            try {

                request = (HttpServletRequest) pageContext.getRequest();

                response = (HttpServletResponse) pageContext.getResponse();

                queryUrl =  response.encodeURL(request.getContextPath() +
                                               url);
            }
            catch (ClassCastException cce) {

                queryUrl = url;
            }
        }
    }

    /**
     *  Encode the builder URL attribute.
     *  @param  url A builder URL for the form, relative to the server root.
     *  @since  Version 0.8 2005-09-12
     */
    public final void setBuilderUrl(final String url) {

        if (url == null) {

            throw new IllegalArgumentException(
                        "Null action not permitted.");
        }
        else {

            HttpServletRequest request = null;

            HttpServletResponse response = null;

            try {

                request = (HttpServletRequest) pageContext.getRequest();

                response = (HttpServletResponse) pageContext.getResponse();

                builderUrl =  response.encodeURL(request.getContextPath() +
                                                 url);
            }
            catch (ClassCastException cce) {

                builderUrl = url;
            }
        }
    }

    /**
     *  Get the query URL attribute.
     *  @return An encoded query URL for the request.
     *  @since  Version 0.8 2005-09-12
     */
    public final String getQueryUrl() {

        return queryUrl;
    }

    /**
     *  Get the builder URL attribute.
     *  @return An encoded builder URL for the request.
     *  @since  Version 0.8 2005-09-12
     */
    public final String getBuilderUrl() {

        return builderUrl;
    }

}
