package com.mkdoc.jspider;

/*
    Created:  2004-12-03
    Issued:   2004-12-03
    Modified: 2004-12-03

    Author:    Philip Shaw <phil@mkdoc.com>
    Copyright: (c) 2004 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import net.javacoding.jspider.api.model.FetchTriedResource;
import net.javacoding.jspider.api.model.HTTPHeader;

import java.util.Date;

/**
 *  Mock <code>FetchTriedResource</code> for testing.
 *  @version    0.1 2004-12-03
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockFetchTriedResource extends MockResource
                                 implements FetchTriedResource {

    /**
     *  The time when the resource was fetched.
     *  @since  Version 0.1 2004-12-03
     */
    protected final Date fetchTime = new Date();

    /**
     *  The HTTP headers retrieved with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected HTTPHeader[] headers;

    /**
     *  The HTTP status associated with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected int httpStatus;

    /**
     *  Get the time when the resource was fetched.
     *  @return The time this resource was fetched.
     *  @since  Version 0.1 2004-12-03
     */
    public final Date getFetchTime() {

        return fetchTime;
    }

    /**
     *  Get the HTTP headers retrieved with this resource.
     *  @return The HTTP headers retreived with this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final HTTPHeader[] getHeaders() {

        return headers;
    }

    /**
     *  Set the HTTP headers associated with this resource.
     *  @param  headers The HTTP headers to assign to this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setHeaders(final HTTPHeader[] headers) {

        this.headers = headers;
    }

    /**
     *  Get the HTTP status associated with this resource.
     *  @return The HTTP status associated with this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final int getHttpStatus() {

        return httpStatus;
    }

    /**
     *  Set the HTTP status associated with this resource.
     *  @param  httpStatus  The HTTP status to assign to
     *          this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setHttpStatus(final int httpStatus) {

        this.httpStatus = httpStatus;
    }

}
