package com.mkdoc.jspider;

/*
    Created:    2004-12-03
    Issued:     2004-12-03
    Modified:   2004-12-03

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2004 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import net.javacoding.jspider.api.model.FetchedResource;

import java.io.InputStream;

/**
 *  Mock JSpider <code>FetchedResource</code> type for testing.
 *  @version    0.1 2004-12-03
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockFetchedResource extends MockFetchTriedResource
                              implements FetchedResource {

    /**
     *  An input stream for the mock resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected InputStream inStream;

    /**
     *  A MIME type for the mock resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected String mime;

    /**
     *  The byte size of the mock resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected int size;

    /**
     *  The elapsed retrieval time for the mock resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected int timeMs;

    /**
     *  Get an input stream for the mock resource.
     *  @return The input stream assigned to this resource
     *          or <code>null</code> if not assigned.
     *  @since  Version 0.1 2004-12-03
     */
    public final InputStream getInputStream() {

        return  inStream;
    }

    /**
     *  Set an input stream for the mock resource.
     *  @param  inStream    An input stream to assign to
     *          this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setInputStream(final InputStream inStream) {

        this.inStream = inStream;
    }

    /**
     *  Get the MIME type for the mock resource.
     *  @return The MIME type assigned to this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final String getMime() {

        return  mime;
    }

    /**
     *  Set the MIME type for the mock resource.
     *  @param  mime    The MIME type to assign to this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setMime(final String mime) {

        this.mime = mime;
    }

    /**
     *  Get the byte size of the mock resource.
     *  @return The byte size assigned to this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final int getSize() {

        return  size;
    }

    /**
     *  Set the byte size for the mock resource.
     *  @param  size    The byte size to assign to this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setSize(final int size) {

        this.size = size;
    }

    /**
     *  Get the elapsed retrieval time for the mock
     *  resource.
     *  @return The elapsed retrieval time assigned to this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final int getTimeMs() {

        return  timeMs;
    }

    /**
     *  Set the elapsed retrieval time for the mock
     *  resource.
     *  @param  timeMs  The elapsed retrieval time to
     *          assign to this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setTimeMs(final int timeMs) {

        this.timeMs = timeMs;
    }

}
