package com.mkdoc.jspider;

/*
    Created:    2004-11-26
    Issued:     2004-11-26
    Modified:   2004-12-03

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2004 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import net.javacoding.jspider.core.util.config.PropertySet;

import java.util.Hashtable;
import java.util.Map;

/**
 *  Mock JSpider <code>PropertySet</code> for testing only.
 *  @version    0.1 2004-11-26
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockPropertySet implements PropertySet {

    /**
     *  Store properties by name.
     *  @since  Version 0.1 2004-11-26
     */
    private Map properties = new Hashtable();

    /**
     *  Get a <code>String</code> property by name.
     *  @return The named property value if present, or
     *          the specified fallback.
     *  @param  name    The named property.
     *  @param  fallback    A fallback value.
     *  @since  Version 0.1 2004-11-26
     */
    public final String getString(final String name,
                                  final String fallback) {

        try {

            Object value = properties.get(name);

            if (value != null) {

                return (String) value;
            }
            else {

                return fallback;
            }
        }
        catch (ClassCastException cce) {

            return fallback;
        }
    }

    /**
     *  Store a <code>String</code> property by name.
     *  @param  name    The named property.
     *  @param  value   The value to be assigned.
     *  @since  Version 0.1 2004-11-26
     */
    public final void setString(final String name,
                                final String value) {

        properties.put(name, value);
    }

    /**
     *  Get a <code>Class</code> property by name.
     *  @return The named property value if present, or
     *          the specified fallback.
     *  @param  name    The named property.
     *  @param  fallback    A fallback value.
     *  @since  Version 0.1 2004-11-26
     */
    public final Class getClass(final String name,
                                final Class fallback) {

        try {

            Object value = properties.get(name);

            if (value != null) {

                return (Class) value;
            }
            else {

                return fallback;
            }
        }
        catch (ClassCastException cce) {

            return fallback;
        }
    }

    /**
     *  Store a <code>Class</code> property by name.
     *  @param  name    The named property.
     *  @param  value   The value to be assigned.
     *  @since  Version 0.1 2004-11-26
     */
    public final void setClass(final String name,
                               final Class value) {

        properties.put(name, value);
    }


    /**
     *  Get an <code>int</code> property by name.
     *  @return The named property value if present, or
     *          the specified fallback.
     *  @param  name    The named property.
     *  @param  fallback    A fallback value.
     *  @since  Version 0.1 2004-11-26
     */
    public final int getInteger(final String name,
                                final int fallback) {

        try {

            Object value = properties.get(name);

            if (value != null) {

                Integer integer = (Integer) value;

                return integer.intValue();
            }
            else {

                return fallback;
            }
        }
        catch (ClassCastException cce) {

            return fallback;
        }
    }

    /**
     *  Store an <code>int</code> property by name.
     *  @param  name    The named property.
     *  @param  value   The value to be assigned.
     *  @since  Version 0.1 2004-11-26
     */
    public final void setInteger(final String name,
                                 final int value) {

        Integer integer = new Integer(value);

        properties.put(name, integer);
    }

    /**
     *  Get a <code>boolean</code> property by name.
     *  @return The named property value if present, or
     *          the specified fallback.
     *  @param  name    The named property.
     *  @param  fallback    A fallback value.
     *  @since  Version 0.1 2004-11-26
     */
    public final boolean getBoolean(final String name,
                                    final boolean fallback) {

        try {

            Object value = properties.get(name);

            if (value != null) {

                Boolean bool = (Boolean) value;

                return bool.booleanValue();
            }
            else {

                return fallback;
            }
        }
        catch (ClassCastException cce) {

            return fallback;
        }
    }

    /**
     *  Store a <code>boolean</code> property by name.
     *  @param  name    The named property.
     *  @param  value   The value to be assigned.
     *  @since  Version 0.1 2004-11-26
     */
    public final void setBoolean(final String name,
                                 final boolean value) {

        Boolean bool = new Boolean(value);

        properties.put(name, bool);
    }

}
