package com.mkdoc.jspider;

/*
    Created:    2004-12-03
    Issued:     2004-12-03
    Modified:   2005-04-12

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2004 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import net.javacoding.jspider.api.model.Decision;
import net.javacoding.jspider.api.model.Folder;
import net.javacoding.jspider.api.model.Resource;
import net.javacoding.jspider.api.model.Site;

import java.net.URL;

import java.util.Date;
import java.util.List;
import java.util.Vector;

/**
 *  Mock <code>Resource</code> type for testing.
 *  @version    0.1 2004-12-03
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockResource implements Resource {

    /**
     *  The time the resource was discovered.
     *  @since  Version 0.1 2004-12-03
     */
    protected final Date foundTime = new Date();

    /**
     *  The current state of the resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected int state;

    /**
     *  A URL representation of the resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected URL url;

    /**
     *  A <code>Site</code> associated with the resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected Site site;

    /**
     *  A <code>Folder</code> associated with the resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected Folder folder;

    /**
     *  The name associated with the resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected String name;

    /**
     *  The resources that refer to this resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected List referrers = new Vector();

    /**
     *  The spider decision associated with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected Decision spiDecision;

    /**
     *  The parse decision associated with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    protected Decision parDecision;

    /**
     *  Get the URL for this resource.
     *  @return The URL for the resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final URL getURL() {

        return url;
    }

    /**
     *  Get the resource URL.
     *  @param  url The URL to assign to the resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setUrl(final URL url) {

        this.url = url;
    }

    /**
     *  Get the file name part of the resource URL.
     *  @return The part of the URL following the last
     *          virtual path separator.
     *  @since  Version 0.1 2004-12-03
     */
    public final String getFileName() {

        return url.getFile();
    }

    /**
     *  Get the current state of this resource.
     *  @return The current state constant.
     *  @since  Version 0.1 2004-12-03
     */
    public final int getState() {

        return state;
    }

    /**
     *  Set the state of this resource.
     *  @param  state   The state constant to assign
     *          to this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setState(final int state) {

        this.state = state;
    }

    /**
     *  Get the state name for this resource.
     *  @return A human readable name for the current
     *          state.
     *  @since  Version 0.1 2004-12-03
     */
    public final String getStateName() {

        switch (state) {

            case STATE_DISCOVERED:
            return "Discovered";

            case STATE_FETCH_ERROR:
            return "Fetch error";

            case STATE_FETCH_IGNORED:
            return "Fetch ignored";

            case STATE_FETCH_FORBIDDEN:
            return "Fetch forbidden";

            case STATE_FETCHED:
            return "Fetched";

            case STATE_PARSE_ERROR:
            return "Parse error";

            case STATE_PARSE_IGNORED:
            return "Parse ignored";

            case STATE_PARSED:
            return "Parsed";

            default:
            return "Unknown state";
        }
    }

    /**
     *  Get the <code>Site</code> reference for this resource.
     *  @return The <code>Site</code> instance associated
     *          with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final Site getSite() {

        return site;
    }

    /**
     *  Set the <code>Site</code> reference for this
     *  resource.
     *  @param  site    A <code>Site</code> instance to
     *          associate with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setSite(final Site site) {

        this.site = site;
    }

    /**
     *  Get the <code>Folder</code> reference for this resource.
     *  @return The <code>Folder</code> instance associated
     *          with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final Folder getFolder() {

        return folder;
    }

    /**
     *  Set the <code>Folder</code> reference for this
     *  resource.
     *  @param  folder  A <code>Folder</code> instance to
     *          associate with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setFolder(final Folder folder) {

        this.folder = folder;
    }

    /**
     *  Get the name associated with this resource.
     *  @return The name associated with this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final String getName() {

        return name;
    }

    /**
     *  Set the name associated with this resource.
     *  @param  name    The name to assign to this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setName(final String name) {

        this.name = name;
    }

    /**
     *  Get the discovery time for this resource.
     *  @return The the moment the resource was discovered.
     *  @since  Version 0.1 2004-12-03
     */
    public final Date getDiscoveryTime() {

        return foundTime;
    }

    /**
     *  Get the resources that refer to this one.
     *  @return Any resources that refer to the current
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final Resource[] getReferers() {

        int size = referrers.size();

        return (Resource[]) referrers.toArray(new Resource[size]);
    }

    /**
     *  Add a referrer to this resource.
     *  @param  referrer    A resource that refers
     *          to the current resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void addReferrer(final Resource referrer) {

        referrers.add(referrer);
    }

    /**
     *  Get the spider decision associated with this
     *  resource.
     *  @return The spider decision associated with this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final Decision getSpiderDecision() {

        return spiDecision;
    }

    /**
     *  Set the spider decision associated with this
     *  resource.
     *  @param  decision    The spider decision to assign
     *          to this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setSpiderDecision(final Decision decision) {

        this.spiDecision = decision;
    }

    /**
     *  Get the parse decision associated with this
     *  resource.
     *  @return The parse decision associated with this
     *          resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final Decision getParseDecision() {

        return parDecision;
    }

    /**
     *  Set the parse decision associated with this
     *  resource.
     *  @param  decision    The parse decision to assign
     *          to this resource.
     *  @since  Version 0.1 2004-12-03
     */
    public final void setParseDecision(final Decision decision) {

        this.parDecision = decision;
    }

}
