package com.mkdoc.query;

/*
    Created:    2005-10-11
    Issued:     2005-10-11
    Modified:   2005-11-01

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.jsp.MockJspWriter;

import com.mkdoc.servlet.MockServletOutputStream;

import java.io.IOException;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 *  Test suite for <code>XhtmlResultRenderer</code>.
 *  @version    0.2 2005-11-01
 *  @author Philip Shaw <phil@mkdoc.com>
 */
public class XhtmlResultRendererTest extends TestCase {

    /**
     *  An expected IllegalArgumentException.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String EXPECTED_IAE =
    "Should throw an IllegalArgumentException.";

    /**
     *  An expected summary message.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String EXPECTED_SUMMARY =
    "Markup should include the summary statement '";

    /**
     *  An expected document type declaration message.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String EXPECTED_DOCTYPE =
    "Markup should not include the document type declaration ";

    /**
     *  An expected document footer message.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String EXPECTED_FOOTER =
    "Markup should not include the document footer ";

    /**
     *  An expected &quot;one of one&quot; result summary.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String ONE_OF_ONE =
    "Result <strong>1</strong> of <strong>1</strong>";

    /**
     *  An expected summary message.
     *  @since  Version 0.1 2005-10-11
     */


    /**
     *  The default page index.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int PAGE_INDEX = 1;

    /**
     *  The default results per page limit.
     *  <p>
     *    Low to make &quot;extreme&quot; paging possible with fewer results.
     *  </p>
     *  @since  Version 0.1 2005-10-11
     */
    public static final int RESULT_LIMIT = 2;

    /**
     *  The number of results pages limit tests.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int LIMIT_RESULTS = 22;

    /**
     *  The first page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int FIRST = 1;

    /**
     *  The second page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int SECOND = 2;

    /**
     *  The third page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int THIRD = 3;

    /**
     *  The fourth page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int FOURTH = 4;

    /**
     *  The fifth page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int FIFTH = 5;

    /**
     *  The sixth page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int SIXTH = 6;

    /**
     *  The tenth page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int TENTH = 10;

    /**
     *  The eleventh page number.
     *  @since  Version 0.1 2005-10-11
     */
    public static final int ELEVENTH = 11;

    /**
     *  The &quot;Next&quot; navigation markup.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String NEXT = ">Next &gt;&gt;</a>";

    /**
     *  The &quot;Should include Next&quot; test failure report.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String SHOULD_NEXT =
    "Markup should include the next navigation '";

    /**
     *  The &quot;previous&quot; navigation markup.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String PREV = ">&lt;&lt; Previous</a>";

    /**
     *  The &quot;previous&quot; navigation markup.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String SHOULD_PREV =
    "Markup should include the previous navigation '";

    /**
     *  The &quot;actual markup&quot; test failure report.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String ACTUAL = "', actual output was:\n\n";

    /**
     *  An SeRQL query.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String QUERY_STRING =
    "SELECT DISTINCT targetUri, createdDate, dcSubject, targetTitle, " +
    "targetSummary FROM {targetUri} dcterms:created {createdDate}, " +
    "     {targetUri} dc:subject {dcSubject}," +
    "     [ {targetUri} dc:title {targetTitle} ], " +
    "     [ {targetUri} dc:description {targetSummary} ] " +
    "WHERE (label(dcSubject) LIKE \"GCJ\" OR " +
    "       label(dcSubject) LIKE \"JSpider\") " +
    "AND label(createdDate) LIKE \"2005-*\" " +
    "UNION " +
    "SELECT DISTINCT targetUri, createdDate, dcSubject, targetTitle,  " +
    "targetSummary FROM {targetUri} dcterms:created {} rdf:value  " +
    "{createdDate}, {targetUri} dc:subject {dcSubject}, " +
    "     [ {targetUri} dc:title {targetTitle} ], " +
    "     [ {targetUri} dc:description {targetSummary} ] " +
    "WHERE (label(dcSubject) LIKE \"GCJ\" OR " +
    "       label(dcSubject) LIKE \"JSpider\") " +
    "AND label(createdDate) LIKE \"2005-*\" " +
    "USING NAMESPACE dc = <http://purl.org/dc/elements/1.1/>, " +
    "            dcterms = <http://purl.org/dc/terms/> ";

    /**
     *  A result key for testing.
     *  @since  Version 0.1 2005-10-12
     */
    public static final String RESULT_KEY =
    "http://localhost/HttpQuery?dcterms.created=2005-*&amp;dc.subject=" +
    "GCJ+JSpider";

    /**
     *  A result key for testing.
     *  @since  Version 0.1 2005-10-12
     */
    public static final String KEY_2 =
    "http://remote.host.com/HttpQuery?dcterms.created=2005-*&amp;dc.subject=" +
    "GCJ+JSpider";

    /**
     *  A result item title.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String TITLE = "Item title";

    /**
     *  A result item summary.
     *  @since  Version 0.1 2005-10-11
     */
    public static final String SUMMARY = "Item summary";

    /**
     *  A result item URI
     *  @since  Version 0.1 2005-10-11
     */
    public static final String URI = "http://remote.example/uri/result-item";

    /**
     *  An XHTML query context.
     *  @since  Version 0.1 2005-10-11
     */
    protected XhtmlQueryContext context;

    /**
     *  A query object.
     *  @since  Version 0.1 2005-10-11
     */
    protected Query query;

    /**
     *  A renderer to test.
     *  @since  Version 0.1 2005-10-11
     */
    protected XhtmlResultRenderer renderer;

    /**
     *  A query result to test.
     *  @since  Version 0.1 2005-10-11
     */
    protected MockQueryResult result;

    /**
     *  Named test instance.
     *  @param  name    The name of the test case.
     *  @since  Version 0.1 2005-10-11
     */
    public XhtmlResultRendererTest(final String name) {

        super(name);
    }

    /**
     *  Set up a test scenario as required.
     *  @since  Version 0.1 2005-10-11
     */
    protected final void setUp() {

        context = new XhtmlQueryContext(PAGE_INDEX,
                                        RESULT_LIMIT);

        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

    }

    /**
     *  Test get start index, null result.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetStartIndexNullResult() {

        try {

            renderer.getStartIndex(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test get start index, null query result object.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetStartIndexNullQueryResultObject() {

        int start = renderer.getStartIndex(new NullQueryResult());

        assertTrue("Start index should be zero, actual start index was " +
                   start,
                   start == 0);
    }

    /**
     *  Test get start index, null query result object.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetStartIndexRequestedPageOutOfBounds() {

        context = new XhtmlQueryContext(SIXTH,
                                        RESULT_LIMIT);

        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, SECOND);

        int start = renderer.getStartIndex(result);

        assertTrue("Start index should not be zero, actual start index was " +
                   start,
                   start == 0);
    }

    /**
     *  Test get end index, null result.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetEndIndexNullResult() {

        try {

            renderer.getEndIndex(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test get end index, null query result object.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetEndIndexNullQueryResultObject() {

        int end = renderer.getEndIndex(new NullQueryResult());

        assertTrue("End index should be zero, actual end index was " +
                   end,
                   end == 0);
    }


    /**
     *  Test set/get query URI.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testSetGetQuery() {

        Query initialQuery = renderer.getQuery();

        Query otherQuery = new SimpleQuery(QUERY_STRING,
                                           KEY_2,
                                           context);

        renderer.setQuery(otherQuery);

        Query testQuery = renderer.getQuery();

        assertTrue(testQuery.equals(otherQuery));

        assertFalse(testQuery.equals(initialQuery));
    }

    /**
     *  Test set/get query URI.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testSetQueryNullQuery() {

        try {

            renderer.setQuery(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test the constructor with a null argument.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testConstructorNullQuery() {

        try {

            new XhtmlResultRenderer(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test the content type.
     *  @since  Version 0.1 2005-10-12
     */
    public final void testGetContentType() {

        String type = renderer.getContentType();

        assertTrue(type.equals("text/html"));
    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNoItems() {

        result = new MockQueryResult(TITLE, SUMMARY, URI, 0);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected = "No results";

        assertTrue(EXPECTED_SUMMARY +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);
    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultFullMode() {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.FULL);

        String markup = buffer.toString();

        assertTrue("Markup should include the document type declaration " +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.HEADER) > -1);

        assertTrue("Markup should include the document footer " +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.FOOTER) > -1);

    }

    /**
     *  Test query result with null result.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNullResult() {

        try {

            renderer.getQueryResult(null,
                                    renderer.INSERT);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }


    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultInsertMode() {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        assertTrue(EXPECTED_DOCTYPE +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.HEADER) == -1);

        assertTrue(EXPECTED_FOOTER +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.FOOTER) == -1);
    }


    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultOneItem() {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected = ONE_OF_ONE;

        assertTrue(EXPECTED_SUMMARY +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);
    }

    /**
     *  Test basic result listing.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testRenderQueryResultServletOutputStream()
         throws IOException {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        MockServletOutputStream outStream = new MockServletOutputStream();

        renderer.renderQueryResult(outStream, result);

        String markup = outStream.getOutput();

        String expected = ONE_OF_ONE;

        assertTrue(EXPECTED_SUMMARY +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);
    }

    /**
     *  Test basic result listing.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testRenderQueryResultNullServletOutputStream()
         throws IOException {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        MockServletOutputStream outStream = null;

        try {

            renderer.renderQueryResult(outStream, result);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }


    /**
     *  Test basic result listing.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testRenderQueryResultServletOutputStreamInsertMode()
        throws IOException {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        MockServletOutputStream outStream = new MockServletOutputStream();

        renderer.renderQueryResult(outStream, result, renderer.INSERT);

        String markup = outStream.getOutput();

        assertTrue(EXPECTED_DOCTYPE +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.HEADER) == -1);

        assertTrue(EXPECTED_FOOTER +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.FOOTER) == -1);
    }

    /**
     *  Test basic result listing.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testRenderQueryResultJspWriter()
         throws IOException {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        MockJspWriter outStream = new MockJspWriter();

        renderer.renderQueryResult(outStream, result);

        String markup = outStream.getOut();

        String expected = ONE_OF_ONE;

        assertTrue(EXPECTED_SUMMARY +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);
    }

    /**
     *  Test basic result listing.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testRenderQueryResultString()
         throws IOException {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        String markup = renderer.renderQueryResult(result, renderer.INSERT);

        String expected = ONE_OF_ONE;

        assertTrue(EXPECTED_SUMMARY +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);

        assertTrue(EXPECTED_DOCTYPE +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.HEADER) == -1);

        assertTrue(EXPECTED_FOOTER +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.FOOTER) == -1);

    }


    /**
     *  Test basic result listing.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testRenderQueryResultNullJspWriter()
         throws IOException {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        MockJspWriter outStream = null;

        try {

            renderer.renderQueryResult(outStream, result);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }


    /**
     *  Test basic result listing.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testRenderQueryResultJspWriterInsertMode()
        throws IOException {

        result = new MockQueryResult(TITLE, SUMMARY, URI, FIRST);

        MockJspWriter outStream = new MockJspWriter();

        renderer.renderQueryResult(outStream, result, renderer.INSERT);

        String markup = outStream.getOut();

        assertTrue(EXPECTED_DOCTYPE +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.HEADER) == -1);

        assertTrue(EXPECTED_FOOTER +
                   ACTUAL +
                   markup,
                   markup.indexOf(XhtmlResultRenderer.FOOTER) == -1);
    }


    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultTwoItems() {

        result = new MockQueryResult(TITLE, SUMMARY, URI, SECOND);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected = "Results <strong>1</strong> to <strong>2</strong> " +
                          "of <strong>2</strong>";

        assertTrue(EXPECTED_SUMMARY +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);
    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultWithNextNavigationOnly() {

        result = new MockQueryResult(TITLE, SUMMARY, URI, THIRD);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected = NEXT;

        String notExpected = PREV;

        assertTrue(SHOULD_NEXT +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);

        assertTrue("Markup should not include the previous navigation '" +
                   notExpected + ACTUAL +
                   markup,
                   markup.indexOf(notExpected) == -1);
    }


    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultWithPreviousNavigationOnly() {

        context = new XhtmlQueryContext(SECOND,
                                        RESULT_LIMIT);


        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, THIRD);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String notExpected = NEXT;

        String expected = PREV;

        assertTrue(SHOULD_PREV +
                   expected + ACTUAL +
                   markup,
                   markup.indexOf(expected) > -1);

        assertTrue("Markup should not include the next navigation '" +
                   notExpected + ACTUAL +
                   markup,
                   markup.indexOf(notExpected) == -1);
    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultWithNextPreviousNavigation() {

        context = new XhtmlQueryContext(SECOND,
                                        RESULT_LIMIT);


        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, SIXTH);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected1 = NEXT;

        String expected2 = PREV;

        assertTrue(SHOULD_PREV +
                   expected2 + ACTUAL +
                   markup,
                   markup.indexOf(expected2) > -1);

        assertTrue(SHOULD_NEXT +
                   expected1 + ACTUAL +
                   markup,
                   markup.indexOf(expected1) > -1);
    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNavigationPageRangeLimitedFirst() {

        result = new MockQueryResult(TITLE, SUMMARY, URI, LIMIT_RESULTS);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected1 = NEXT;

        String expected2 = "<strong>1</strong>";

        String expected3 = ">9</a>";

        String unexpected1 = ">10</a>";

        String unexpected2 = PREV;

        assertTrue(SHOULD_NEXT +
                   expected1 + ACTUAL +
                   markup,
                   markup.indexOf(expected1) > -1);

        assertTrue("Markup should include the first page indicator'" +
                   expected2 + ACTUAL +
                   markup,
                   markup.indexOf(expected2) > -1);

        assertTrue("Markup should include the ninth page link'" +
                   expected3 + ACTUAL +
                   markup,
                   markup.indexOf(expected3) > -1);

        assertTrue("Markup should not include the tenth page link'" +
                   unexpected1 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected1) == -1);

        assertTrue("Markup should not include the previous navigation '" +
                   unexpected2 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected2) == -1);

    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNavigationPageRangeLimitedFourth() {

        context = new XhtmlQueryContext(FOURTH,
                                        RESULT_LIMIT);


        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, LIMIT_RESULTS);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected1 = NEXT;

        String expected2 = PREV;

        String expected3 = "<strong>4</strong>";

        String expected4 = ">1</a>";

        String unexpected1 = ">10</a>";

        assertTrue(SHOULD_NEXT +
                   expected1 + ACTUAL +
                   markup,
                   markup.indexOf(expected1) > -1);

        assertTrue(SHOULD_PREV +
                   expected2 + ACTUAL +
                   markup,
                   markup.indexOf(expected2) > -1);

        assertTrue("Markup should include the fourth page marker '" +
                   expected3 + ACTUAL +
                   markup,
                   markup.indexOf(expected3) > -1);

        assertTrue("Markup should include the first page link'" +
                   expected4 + ACTUAL +
                   markup,
                   markup.indexOf(expected4) > -1);

        assertTrue("Markup should not include the tenth page link'" +
                   unexpected1 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected1) == -1);

    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNavigationPageRangeLimitedFifth() {

        context = new XhtmlQueryContext(FIFTH,
                                        RESULT_LIMIT);


        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, LIMIT_RESULTS);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected1 = NEXT;

        String expected2 = PREV;

        String expected3 = "<strong>5</strong>";

        String expected4 = ">10</a>";

        String unexpected1 = ">1</a>";

        String unexpected2 = ">11</a>";

        assertTrue(SHOULD_NEXT +
                   expected1 + ACTUAL +
                   markup,
                   markup.indexOf(expected1) > -1);

        assertTrue(SHOULD_PREV +
                   expected2 + ACTUAL +
                   markup,
                   markup.indexOf(expected2) > -1);

        assertTrue("Markup should include the fifth page marker '" +
                   expected3 + ACTUAL +
                   markup,
                   markup.indexOf(expected3) > -1);

        assertTrue("Markup should include the tenth page link'" +
                   expected4 + ACTUAL +
                   markup,
                   markup.indexOf(expected4) > -1);

        assertTrue("Markup should not include the first page link'" +
                   unexpected1 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected1) == -1);

        assertTrue("Markup should not include the eleventh page link'" +
                   unexpected2 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected2) == -1);

    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNavigationPageRangeLimitedSixth() {

        context = new XhtmlQueryContext(SIXTH,
                                        RESULT_LIMIT);


        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, LIMIT_RESULTS);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected1 = ">11</a>";

        String expected2 = PREV;

        String expected3 = "<strong>6</strong>";

        String expected4 = NEXT;

        String unexpected1 = ">2</a>";

        String unexpected2 = ">12</a>";

        assertTrue("Markup should include the eleventh page navigation '" +
                   expected1 + ACTUAL +
                   markup,
                   markup.indexOf(expected1) > -1);

        assertTrue(SHOULD_PREV +
                   expected2 + ACTUAL +
                   markup,
                   markup.indexOf(expected2) > -1);

        assertTrue("Markup should include the sixth page marker '" +
                   expected3 + ACTUAL +
                   markup,
                   markup.indexOf(expected3) > -1);

        assertTrue("Markup should include a next page link'" +
                   expected4 + ACTUAL +
                   markup,
                   markup.indexOf(expected4) > -1);

        assertTrue("Markup should not include the second page link'" +
                   unexpected1 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected1) == -1);


        assertTrue("Markup should not include a twelvth page link'" +
                   unexpected2 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected2) == -1);

    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNavigationPageRangeLimitedTenth() {

        context = new XhtmlQueryContext(TENTH,
                                        RESULT_LIMIT);


        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, LIMIT_RESULTS);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected1 = ">3</a>";

        String expected2 = PREV;

        String expected3 = "<strong>10</strong>";

        String expected4 = NEXT;

        String expected5 = ">11</a>";

        String unexpected1 = ">2</a>";

        String unexpected2 = ">12</a>";


        assertTrue("Markup should include the third page navigation '" +
                   expected1 + ACTUAL +
                   markup,
                   markup.indexOf(expected1) > -1);

        assertTrue(SHOULD_PREV +
                   expected2 + ACTUAL +
                   markup,
                   markup.indexOf(expected2) > -1);

        assertTrue("Markup should include the tenth page marker '" +
                   expected3 + ACTUAL +
                   markup,
                   markup.indexOf(expected3) > -1);

        assertTrue("Markup should include the next page navigation '" +
                   expected4 + ACTUAL +
                   markup,
                   markup.indexOf(expected4) > -1);

        assertTrue("Markup should include the eleventh page navigation '" +
                   expected5 + ACTUAL +
                   markup,
                   markup.indexOf(expected5) > -1);

        assertTrue("Markup should not include the second page link'" +
                   unexpected1 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected1) == -1);

        assertTrue("Markup should not include a twelvth page link'" +
                   unexpected2 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected2) == -1);

    }

    /**
     *  Test basic result listing.
     *  @since  Version 0.1 2005-10-11
     */
    public final void testGetQueryResultNavigationPageRangeLimitedEleventh() {

        context = new XhtmlQueryContext(ELEVENTH,
                                        RESULT_LIMIT);


        query = new SimpleQuery(QUERY_STRING,
                                RESULT_KEY,
                                context);

        renderer = new XhtmlResultRenderer(query);

        result = new MockQueryResult(TITLE, SUMMARY, URI, LIMIT_RESULTS);

        StringBuffer buffer = renderer.getQueryResult(result, renderer.INSERT);

        String markup = buffer.toString();

        String expected1 = ">3</a>";

        String expected2 = PREV;

        String expected3 = "<strong>11</strong>";

        String unexpected1 = ">2</a>";

        String unexpected2 = ">12</a>";

        String unexpected3 = NEXT;


        assertTrue("Markup should include the third page navigation '" +
                   expected1 + ACTUAL +
                   markup,
                   markup.indexOf(expected1) > -1);

        assertTrue(SHOULD_PREV +
                   expected2 + ACTUAL +
                   markup,
                   markup.indexOf(expected2) > -1);

        assertTrue("Markup should include the eleventh page marker '" +
                   expected3 + ACTUAL +
                   markup,
                   markup.indexOf(expected3) > -1);

        assertTrue("Markup should not include the second page link'" +
                   unexpected1 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected1) == -1);


        assertTrue("Markup should not include a twelvth page link'" +
                   unexpected2 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected2) == -1);

        assertTrue("Markup should not include a next page link'" +
                   unexpected3 + ACTUAL +
                   markup,
                   markup.indexOf(unexpected3) == -1);
    }






    /**
     *  Tear down a test scenario as required.
     *  @since  Version 0.1 2005-10-11
    protected void tearDown() {

    }
     */

    /**
     *  Create a test suite for this test case.
     *  @return A test suite.
     *  @since  Version 0.1 2005-10-11
     */
    public static Test suite() {

        return new TestSuite(XhtmlResultRendererTest.class);
    }

    /**
     *  Run this test suite as a stand alone application.
     *  @param  args    Any command line arguments to pass
     *          to the test. None required or expected.
     *  @since  Version 0.1 2005-10-11
     */
    public static void main(final String[] args) {

        junit.textui.TestRunner.run(suite());
    }

}
