package com.mkdoc.sax;

/*
    Created:    2005-02-14
    Issued:     2005-02-14
    Modified:   2005-10-21

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.io.MockOutputStream;

import com.mkdoc.schema.ApplicationProfile;
import com.mkdoc.schema.Schema;
import com.mkdoc.schema.UKeGMS;
import com.mkdoc.schema.UKeGMSProfile;

import com.mkdoc.store.MockVirtualFileStoreManager;

import java.io.PrintWriter;

import java.io.IOException;

import java.net.URL;

import org.xml.sax.SAXException;

import org.xml.sax.helpers.AttributesImpl;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 *  Test suite for <code>LinkTripleWriter</code>.
 *  @version    0.9 2005-10-21
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class LinkTripleWriterTest extends TestCase {

    /**
     *  An &quot;actual output&quot; statement for test failures.
     *  @since  Version 1.5 2005-10-21
     */
    protected static final String ACTUALLY =
    "Output actually equals:\n";

    /**
     *  A &quot;should not ...&quot; statement for test failures.
     *  @since  Version 1.5 2005-10-21
     */
    protected static final String SHOULD_NOT =
    "Should not give any output, actually: '";

    /**
     *  An &quot;expected bNode&quot; statement for test failures.
     *  @since  Version 1.5 2005-10-21
     */
    protected static final String EXPECT_BNODE =
    "The triple output should include the bNode:\n";

    /**
     *  An &quot;expected bNode type&quot; statement for test failures.
     *  @since  Version 1.5 2005-10-21
     */
    protected static final String SHOULD_TYPE =
    "The triple output should include the bNode type:\n";

    /**
     *  An &quot;expected bNode value&quot; statement for test failures.
     *  @since  Version 1.5 2005-10-21
     */
    protected static final String BNODE_VALUE =
    "The triple output should include the bNode value:\n";

    /**
     *  An initial test URI.
     *  @since  Version 0.1 2005-02-14
     */
    protected static final String URI_1 =
    "http://www.remote.example/test/page.html";

    /**
     *  A second test URI.
     *  @since  Version 0.1 2005-02-14
     */
    protected static final String URI_2 =
    "http://www.remote.example/second/page.html";

    /**
     *  The XHTML namespace URI.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String NAMESPACE = "http://www.w3.org/1999/xhtml";

    /**
     *  An XHTML <code>head</code> element local name.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String HEAD = "head";

    /**
     *  An XHTML <code>link</code> element local name.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String LINK = "link";

    /**
     *  An XHTML <code>rel</code> attribute local name.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String REL = "rel";

    /**
     *  A qualified XHTML <code>rel</code> attribute.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String QUAL_REL = NAMESPACE +
                                           ":" +
                                           REL;

    /**
     *  An XHTML <code>rev</code> attribute local name.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String REV = "rev";

    /**
     *  A qualified XHTML <code>rev</code> attribute.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String QUAL_REV = NAMESPACE +
                                           ":" +
                                           REV;

    /**
     *  An XHTML <code>href</code> attribute local name.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String HREF = "href";

    /**
     *  A qualified XHTML <code>rel</code> attribute.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String QUAL_HREF = NAMESPACE +
                                            ":" +
                                            HREF;

    /**
     *  A generic XHTML <code>top</code> rel value.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String REL_GENERIC = "top";

    /**
     *  A generic XHTML <code>top</code> content
     *  value.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String HREF_GENERIC =
    "HTTP://test.mksearch.mkdoc.org/test/generic";

    /**
     *  A DC rights predicate.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String DC_RIGHTS = "DC.Rights";

    /**
     *  The DC rights URI.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String URI_RIGHTS =
    "http://purl.org/dc/elements/1.1/rights";

    /**
     *  A DC rights object URI value.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String HREF_RIGHTS =
    "http://test.mksearch.mkdoc.org/test/rights";

    /**
     *  A DC rights object URI value.
     *  @since  Version 0.8 2005-09-09
     */
    private static final String HREF_PADDED =
    " http://test.mksearch.mkdoc.org/test/rights ";

    /**
     *  A line separator.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String NEW_LINE = System.getProperty("line.separator");

    /**
     *  A (partial) triple set with bNode for DC rights -- forward reference.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String T3_BNODE_REL = " <" + URI_1 + "> " +
                           "<" + URI_RIGHTS + "> " +
                           "_:mkdoc";

    /**
     *  A (partial) triple set with bNode for DC rights -- reverse reference.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String T3_BNODE_REV = " <" + HREF_RIGHTS + "> " +
                           "<" + URI_RIGHTS + "> " +
                           "_:mkdoc";

    /**
     *  A partial triple set for a bNode with RDF type.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String BNODE_TYPE = // Variable bNode omitted
                 "<http://www.w3.org/1999/02/22-rdf-syntax-ns#type> " +
                 "<http://purl.org/dc/terms/URI> ." +
                 NEW_LINE;

    /**
     *  A triple set for a bNode with RDF value -- forward reference.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String VALUE_REL = // Variable bNode omitted
                  "<http://www.w3.org/1999/02/22-rdf-syntax-ns#value> " +
                  "<" + HREF_RIGHTS + "> ." +
                  NEW_LINE;

    /**
     *  A triple set for a bNode with RDF value -- reverse reference.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String VALUE_REV = // Variable bNode omitted
                  "<http://www.w3.org/1999/02/22-rdf-syntax-ns#value> " +
                  "<" + URI_1 + "> ." +
                  NEW_LINE;

    /**
     *  A qualified XHTML <code>link</code> element name.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String QUAL_LINK = NAMESPACE +
                                            ":" +
                                            LINK;

    /**
     *  A qualified XHTML <code>head</code> element name.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String QUAL_HEAD = NAMESPACE +
                                            ":" +
                                            HEAD;

    /**
     *  A CDATA type string.
     *  @since  Version 0.1 2005-02-14
     */
    private static final String CDATA = "CDATA";

    /**
     *  An expected <code>IllegalArgumentException</code>.
     *  @since  Version 0.2 2005-02-15
     */
    private static final String EXPECT_IAE =
    "Should throw an IllegalArgumentException.";

    /**
     *  A test subject URI.
     *  @since  Version 0.2 2005-02-15
     */
    private static final String URI_SUBJ_1 =
    "http://www.mkdoc.org/uri/test/LinkTripleWriter#one";

    /**
     *  An empty attribute set for testing.
     *  @since  Version Version 0.1 2005-02-14
     */
    private AttributesImpl attributes;

    /**
     *  A general test content handler.
     *  @since  Version 0.1 2005-02-14
     */
    protected LinkTripleWriter tripleWriter;

    /**
     *  A default instance for testing.
     *  @since  Version 0.1 2005-02-14
     */
    protected LinkTripleWriter basicWriter;

    /**
     *  A mock subject manager to check output.
     *  @since  Version 0.1 2005-02-14
     */
    protected MockVirtualFileStoreManager manager;

    /**
     *  An output stream for the test content handler.
     *  @since  Version 0.1 2005-02-14
     */
    protected MockOutputStream outStream;

    /**
     *  Named test instance.
     *  @param  name    The name of the test case.
     *  @since  Version 0.1 2005-02-14
     */
    public LinkTripleWriterTest(final String name) {

        super(name);
    }

    /**
     *  Set up a test scenario as required.
     *  @exception  IOException Should not be thrown in set up.
     *  @since  Version 0.1 2004-
     */
    protected final void setUp() throws IOException {

        outStream = new MockOutputStream();

        manager = new MockVirtualFileStoreManager(outStream);

        tripleWriter = new LinkTripleWriter(manager,
                                            new URL(URI_1));

        attributes = new AttributesImpl();

        basicWriter = new LinkTripleWriter();

    }

    /**
     *  Test constructor with custom application profile.
     *  @since  Version 0.6 2005-05-25
     */
    public final void testConstructorNullApplicationProfile() {

        ApplicationProfile profile = null;

        try {

            new LinkTripleWriter(profile);

            fail("Should throw an IllegalArgumentException.");
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test constructor with custom schema map.
     *  @since  Version 0.6 2005-05-25
     */
    public final void testConstructorCustomApplicationProfile() {

        Schema egms = new UKeGMS();

        ApplicationProfile profile = new UKeGMSProfile();

        LinkTripleWriter customWriter = new LinkTripleWriter(profile);

        String predicate = "egms.Mandate";

        String expanded = customWriter.expandPredicate(predicate);

        String uri = egms.getUri() + "mandate";

        assertTrue("Should expand the predicate to the URI " +
                   uri + ", actually returned '" +
                   expanded + "'.",
                   expanded.equals(uri));
    }

    /**
     *  Check whether an element is accepted.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testAcceptElementNullUri() {

        try {

            tripleWriter.acceptElement(null,
                                       LINK);

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Check whether an element is accepted.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testAcceptElementNullLocalName() {

        try {

            tripleWriter.acceptElement(NAMESPACE,
                                       null);

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Check whether an element is accepted.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testAcceptElementFalse() {


        assertFalse(tripleWriter.acceptElement("http://example.org/1999/xhtml",
                                               LINK));
    }

    /**
     *  Check whether an element is accepted.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testAcceptElementTrue() {


        assertTrue(tripleWriter.acceptElement(NAMESPACE,
                                              LINK));
    }

    /**
     *  Add triples with null argument.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testPrintTriplesNullSourceUri() {

        PrintWriter writer =  new PrintWriter(outStream);

        try {

            tripleWriter.printTriples(null,
                                      attributes,
                                      writer);

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Add triples with null argument.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testPrintTriplesNullAttributes() {

        PrintWriter writer =  new PrintWriter(outStream);

        try {

            tripleWriter.printTriples(URI_SUBJ_1,
                                      null,
                                      writer);

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Add triples with null argument.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testPrintTriplesNullPrintWriter() {

        try {

            tripleWriter.printTriples(URI_SUBJ_1,
                                      attributes,
                                      null);

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Start a <code>link</code> element with a default instance.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testStartElementDefaultInstance() {

        try {

            basicWriter.startElement(NAMESPACE,
                                     LINK,
                                     QUAL_LINK,
                                     attributes);

            fail("Should throw a SAXException.");
        }
        catch (SAXException se) { }

    }

    /**
     *  Start a <code>link</code> element with a default instance.
     *  @since  Version 0.2 2005-02-15
     */
    public final void testStartElementDefaultInstanceWithSubject() {

        basicWriter.setSubject(URI_SUBJ_1);

        try {

            basicWriter.startElement(NAMESPACE,
                                     LINK,
                                     QUAL_LINK,
                                     attributes);

            fail("Should throw a SAXException.");
        }
        catch (SAXException se) { }

    }

    /**
     *  XHTML <code>link</code> basic attributes.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.1 2004-12-17
     */
    public final void testStartElementGeneric() throws SAXException {

        attributes.addAttribute(NAMESPACE,
                                REL,
                                QUAL_REL,
                                CDATA,
                                REL_GENERIC);

        attributes.addAttribute(NAMESPACE,
                                HREF,
                                QUAL_HREF,
                                CDATA,
                                HREF_GENERIC);

        tripleWriter.startDocument();

        outStream.reset();

        tripleWriter.startElement(NAMESPACE,
                                  LINK,
                                  QUAL_LINK,
                                  attributes);

        String start = outStream.getOutput();

        assertTrue("Should be no triple output when predicate " +
                   "is not expanded to a URI. '" +
                   "Actual output: '" + start + "'.",
                   start.equals(""));
    }

    /**
     *  XHTML <code>link</code> with schema prefix, <code>rel</code> attribute.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testStartElementSchemaRel() throws SAXException {

        attributes.addAttribute(NAMESPACE,
                                REL,
                                QUAL_REL,
                                CDATA,
                                DC_RIGHTS);

        attributes.addAttribute(NAMESPACE,
                                HREF,
                                QUAL_HREF,
                                CDATA,
                                HREF_RIGHTS);

        tripleWriter.startDocument();

        outStream.reset();

        tripleWriter.startElement(NAMESPACE,
                                  LINK,
                                  QUAL_LINK,
                                  attributes);

        String start = outStream.getOutput();

        assertTrue(EXPECT_BNODE +
                   T3_BNODE_REL + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(T3_BNODE_REL) > -1));

        assertTrue(SHOULD_TYPE +
                   BNODE_TYPE + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(BNODE_TYPE) > -1));

        assertTrue("The triple output should include the bNode value:\n" +
                   VALUE_REL + "\n" +
                   "actually equals:\n" +
                   start,
                   (start.indexOf(VALUE_REL) > -1));
    }

    /**
     *  XHTML <code>link</code> with excess white space.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.8 2005-09-09
     */
    public final void testStartElementSchemaRelTrim() throws SAXException {

        attributes.addAttribute(NAMESPACE,
                                REL,
                                QUAL_REL,
                                CDATA,
                                DC_RIGHTS);

        attributes.addAttribute(NAMESPACE,
                                HREF,
                                QUAL_HREF,
                                CDATA,
                                HREF_PADDED);

        tripleWriter.startDocument();

        outStream.reset();

        tripleWriter.startElement(NAMESPACE,
                                  LINK,
                                  QUAL_LINK,
                                  attributes);

        String start = outStream.getOutput();

        assertTrue(EXPECT_BNODE +
                   T3_BNODE_REL + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(T3_BNODE_REL) > -1));

        assertTrue(SHOULD_TYPE +
                   BNODE_TYPE + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(BNODE_TYPE) > -1));

        assertTrue("The triple output should include the bNode value:\n" +
                   VALUE_REL + "\n" +
                   "actually equals:\n" +
                   start,
                   (start.indexOf(VALUE_REL) > -1));
    }

    /**
     *  XHTML <code>link</code> with schema prefix, <code>rev</code> attribute.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testStartElementSchemaRev() throws SAXException {

        attributes.addAttribute(NAMESPACE,
                                REV,
                                QUAL_REV,
                                CDATA,
                                DC_RIGHTS);

        attributes.addAttribute(NAMESPACE,
                                HREF,
                                QUAL_HREF,
                                CDATA,
                                HREF_RIGHTS);

        tripleWriter.startDocument();

        outStream.reset();

        tripleWriter.startElement(NAMESPACE,
                                  LINK,
                                  QUAL_LINK,
                                  attributes);

        String start = outStream.getOutput();

        assertTrue(EXPECT_BNODE +
                   T3_BNODE_REV + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(T3_BNODE_REV) > -1));

        assertTrue(SHOULD_TYPE +
                   BNODE_TYPE + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(BNODE_TYPE) > -1));

        assertTrue("The triple output should include the bNode value:\n" +
                   VALUE_REV + "\n" +
                   "actually equals:\n" +
                   start,
                   (start.indexOf(VALUE_REV) > -1));
    }

    /**
     *  XHTML <code>link</code> with excessive white space.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.8 2005-09-09
     */
    public final void testStartElementSchemaRevTrim() throws SAXException {

        attributes.addAttribute(NAMESPACE,
                                REV,
                                QUAL_REV,
                                CDATA,
                                DC_RIGHTS);

        attributes.addAttribute(NAMESPACE,
                                HREF,
                                QUAL_HREF,
                                CDATA,
                                HREF_PADDED);

        tripleWriter.startDocument();

        outStream.reset();

        tripleWriter.startElement(NAMESPACE,
                                  LINK,
                                  QUAL_LINK,
                                  attributes);

        String start = outStream.getOutput();

        assertTrue(EXPECT_BNODE +
                   T3_BNODE_REV + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(T3_BNODE_REV) > -1));

        assertTrue(SHOULD_TYPE +
                   BNODE_TYPE + "\n" +
                   ACTUALLY +
                   start,
                   (start.indexOf(BNODE_TYPE) > -1));

        assertTrue(BNODE_VALUE +
                   VALUE_REV + "\n" +
                   "actually equals:\n" +
                   start,
                   (start.indexOf(VALUE_REV) > -1));
    }

    /**
     *  XHTML <code>link</code> no <code>rel</code>
     *  attribute, should not generate a triple.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.1 2004-12-17
     */
    public final void testStartElementNoRelAttr() throws SAXException {

        attributes.addAttribute(NAMESPACE,
                                HREF,
                                QUAL_HREF,
                                CDATA,
                                HREF_RIGHTS);

        tripleWriter.startDocument();

        outStream.reset();

        tripleWriter.startElement(NAMESPACE,
                                  LINK,
                                  QUAL_LINK,
                                  attributes);

        String output = outStream.getOutput();

        assertTrue(SHOULD_NOT + output + "'.",
                   output.equals(""));

    }

    /**
     *  XHTML <code>link</code> no <code>href</code>
     *  attribute, should not generate a triple.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.1 2004-12-17
     */
    public final void testStartElementNoHrefAttr() throws SAXException {

        attributes.addAttribute(NAMESPACE,
                                REL,
                                QUAL_REL,
                                CDATA,
                                DC_RIGHTS);

        tripleWriter.startDocument();

        outStream.reset();

        tripleWriter.startElement(NAMESPACE,
                                  LINK,
                                  QUAL_LINK,
                                  attributes);

        String output = outStream.getOutput();

        assertTrue(SHOULD_NOT + output + "'.",
                   output.equals(""));
    }

    /**
     *  XHTML <code>head</code> elements should throw a
     *  <code>SAXException</code>.
     *  @exception  SAXException Should not be thrown by this test.
     *  @since  Version 0.1 2004-12-17
     */
    public final void testStartElementHeadElement() throws SAXException {

        tripleWriter.startDocument();

        outStream.reset();

        try {

            tripleWriter.startElement(NAMESPACE,
                                      HEAD,
                                      QUAL_HEAD,
                                      attributes);

            fail("Should throw a SAXException.");
        }
        catch (SAXException se) { }

    }

    /**
     *  Should output an initial comment line that includes
     *  the subject URI.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testStartDocument() throws SAXException {

        tripleWriter.startDocument();

        String start = outStream.getOutput();

        assertTrue("Output should start with a comment and include the " +
                   "subject URI. Actual output: '" + start + "'.",
                   (start.indexOf("#") == 0) &&
                   (start.indexOf(URI_1) > -1));

    }

    /**
     *  Should output a new line and end.
     *  @exception  SAXException    Should not be thrown by
     *          this test.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testEndDocument() throws SAXException {

        tripleWriter.startDocument();

        tripleWriter.endDocument();

        String newline = System.getProperty("line.separator");

        String end = outStream.getOutput();

        String veryEnd = end.substring(end.length() - newline.length(),
                                       end.length());

        assertTrue("Output should end with a new line." +
                   "Very end was '" + end + "'.",
                   veryEnd.equals(newline));

    }


    /**
     *  Set null subject should throw an
     *  <code>IllegalArgumentException</code>.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testSetSubjectNull() {

        try {

            tripleWriter.setSubject(null);

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Should adopt the new URI reference.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testSetGetSubject() {

        assertTrue(URI_1.equals(tripleWriter.getSubject()));

        tripleWriter.setSubject(URI_2);

        assertTrue(URI_2.equals(tripleWriter.getSubject()));
    }

    /**
     *  Constructor with null subject manager should throw an
     *  <code>IllegalArgumentException</code>.
     *  @exception  IOException Should not be thrown by this test.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testConstructorNullSubjectManager() throws IOException {

        try {

            tripleWriter = new LinkTripleWriter(null,
                                                new URL(URI_1));

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Constructor with null URI should throw an
     *  <code>IllegalArgumentException</code>.
     *  @since  Version 0.1 2005-02-14
     */
    public final void testConstructorNullUri() {

        try {

            tripleWriter = new LinkTripleWriter(manager,
                                                null);

            fail(EXPECT_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }


    /**
     *  Tear down a test scenario as required.
     *  @since  Version 0.1 2004-
    protected void tearDown() {

    }
     */

    /**
     *  Create a test suite for this test case.
     *  @return A test suite.
     *  @since  Version 0.1 2005-02-14
     */
    public static Test suite() {

        return new TestSuite(LinkTripleWriterTest.class);
    }

    /**
     *  Run this test suite as a stand alone application.
     *  @param  args    Any command line arguments to pass
     *          to the test. None required or expected.
     *  @since  Version 0.1 2005-02-14
     */
    public static void main(final String[] args) {

        junit.textui.TestRunner.run(suite());
    }

}
