package com.mkdoc.sax;

/*
    Created:    2004-12-15
    Issued:     2004-12-15
    Modified:   2004-12-16

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2004 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

/**
 *  A mock <code>ContentHandler</code> for testing.
 *  @version    0.2 2004-12-16
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockContentHandler extends AbstractContentHandler
                             implements ContentHandler {

    /**
     *  A log for handler events.
     *  @since  Version 0.1 2004-12-15
     */
    private StringBuffer eventLog = new StringBuffer();

    /**
     *  Process the start element event.
     *  @param  uri The namespace URI for the element.
     *  @param  localName   The local element name.
     *  @param  qName   The qualified element name.
     *  @param  atts    A set of attributes.
     *  @exception  SAXException    Never thrown by this
     *          implementation.
     *  @since  Version 0.1 2004-12-10
     */
    public final void startElement(final String uri,
                                   final String localName,
                                   final String qName,
                                   final Attributes atts)
        throws SAXException {

        eventLog.append("Start: ");
        eventLog.append(localName);


        int attributes = atts.getLength();

        if (attributes > 0) {

            eventLog.append(", attributes: ");

            for (int i = 0; i < attributes; i++) {

                eventLog.append(atts.getLocalName(i));
                eventLog.append("=");
                eventLog.append(atts.getValue(i));
            }
        }
        eventLog.append(".\n");
    }

    /**
     *  Process the start element through the superclass.
     *  @param  uri The namespace URI for the element.
     *  @param  localName   The local element name.
     *  @param  qName   The qualified element name.
     *  @param  atts    A set of attributes.
     *  @exception  SAXException    Never thrown by this
     *          implementation.
     *  @since  Version 0.2 2004-12-16
     */
    public final void superStartElement(final String uri,
                                        final String localName,
                                        final String qName,
                                        final Attributes atts)
        throws SAXException {

        super.startElement(uri, localName, qName, atts);
    }

    /**
     *  Process the end element event.
     *  @param  uri The namespace URI for the element.
     *  @param  localName   The local element name.
     *  @param  qName   The qualified element name.
     *  @exception  SAXException    Never thrown by this
     *          implementation.
     *  @since  Version 0.1 2004-12-10
     */
    public final void endElement(final String uri,
                                 final String localName,
                                 final String qName)
        throws SAXException {

        eventLog.append("End: ");
        eventLog.append(localName);

    }

    /**
     *  Process the end element event.
     *  @param  uri The namespace URI for the element.
     *  @param  localName   The local element name.
     *  @param  qName   The qualified element name.
     *  @exception  SAXException    Never thrown by this
     *          implementation.
     *  @since  Version 0.1 2004-12-10
     */
    public final void superEndElement(final String uri,
                                      final String localName,
                                      final String qName)
        throws SAXException {

        super.endElement(uri, localName, qName);
    }

    /**
     *  Get the event log.
     *  @return The contents of the event log since
     *          initialisation.
     *  @since  Version 0.1 2004-12-15
     */
    public final String getEventLog() {

        return eventLog.toString();
    }

}
