package com.mkdoc.schema;

/*
    Created:    2005-10-21
    Issued:     2005-10-21
    Modified:   2005-10-21

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import java.util.List;
import java.util.Locale;
import java.util.Vector;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 *  Test suite for <code>DCTermProperty</code>.
 *  @version    0.2 2005-10-21
 *  @author Philip Shaw <phil@mkdoc.com>
 */
public class DCTermPropertyTest extends TestCase {


    /**
     *  Namespace prefix for properties.
     *  @since  Version 0.1 2005-10-21
     */
    protected static final String PREFIX = "dcterms";

    /**
     *  A property label.
     *  @since  Version 0.2 2005-10-21
     */
    protected static final String LABEL = "Title";

    /**
     *  A property name.
     *  @since  Version 0.1 2005-10-21
     */
    protected static final String NAME = "title";

    /**
     *  Base URI for properties.
     *  @since  Version 0.1 2005-10-21
     */
    protected static final String BASE = "http://purl.org/dc/terms/";

    /**
     *  Named test instance.
     *  @param  name    The name of the test case.
     *  @since  Version 0.1 2005-10-21
     */
    public DCTermPropertyTest(final String name) {

        super(name);
    }

    /**
     *  Set up a test scenario as required.
     *  @since  Version 0.1 2005-10-21
    protected void setUp() {

    }
     */

    /**
     *  Test the constructor, null arguments.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testConstructorNullUri() {

        try {

            new DCTermProperty(null, LABEL, NAME);

            fail("Should throw an IllegalArgumentException.");
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Test the constructor, null arguments.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testConstructorNullLabel() {

        try {

            new DCTermProperty(BASE + NAME, null, NAME);

            fail("Should throw an IllegalArgumentException.");
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Test the constructor, null arguments.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testConstructorNullName() {

        try {

            new DCTermProperty(BASE + NAME, LABEL, null);

            fail("Should throw an IllegalArgumentException.");
        }
        catch (IllegalArgumentException iae) { }

    }


    /**
     *  Test the constructor, invalid arguments.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testConstructorInvalidUriEncoding() {

        DCTermProperty property = new DCTermProperty(BASE + NAME,
                                                           LABEL,
                                                           NAME,
                                                           false,
                                                           true);

        assertFalse(property.hasUriEncodingScheme());
    }

    /**
     *  Test the constructor, with encoding.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testConstructorWithEncoding() {

        DCTermProperty property = new DCTermProperty(BASE + NAME,
                                                           LABEL,
                                                           NAME,
                                                           true);

        assertTrue(property.hasEncodingScheme());
        assertFalse(property.hasUriEncodingScheme());
    }

    /**
     *  Test the constructor, with encoding.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testConstructorInvalidNoEncoding() {

        DCTermProperty property = new DCTermProperty(BASE + NAME,
                                                           LABEL,
                                                           NAME,
                                                           false);

        assertFalse(property.hasEncodingScheme());
        assertFalse(property.hasUriEncodingScheme());
    }

    /**
     *  Test the constructor, with encoding.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testConstructorInvalidWithUriEncoding() {

        DCTermProperty property = new DCTermProperty(BASE + NAME,
                                                           LABEL,
                                                           NAME,
                                                           true,
                                                           true);

        assertTrue(property.hasEncodingScheme());
        assertTrue(property.hasUriEncodingScheme());
    }


    /**
     *  Test the namespace prefix.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testGetNamespacePrefix() {

        DCTermProperty property = new DCTermProperty(BASE + NAME,
                                                           LABEL,
                                                           NAME);

        assertTrue(PREFIX.equals(property.getNamespacePrefix()));
    }

    /**
     *  Test the namespace URI.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testGetNamespaceUri() {

        DCTermProperty property = new DCTermProperty(BASE + NAME,
                                                           LABEL,
                                                           NAME);

        assertTrue(BASE.equals(property.getNamespaceUri()));
    }

    /**
     *  Test the locale.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testGetLocale() {

        DCTermProperty property = new DCTermProperty(BASE + NAME,
                                                           LABEL,
                                                           NAME);

        Locale expected = Locale.US;

        assertTrue(expected.equals(property.getLocale()));
    }

    /**
     *  Check equivalence.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testEqualsNull() {

        DCTermProperty property1 = new DCTermProperty(BASE + NAME,
                                                            LABEL,
                                                            NAME);

        DCTermProperty nullProperty = null;

        assertFalse(property1.equals(nullProperty));
    }

    /**
     *  Check equivalence.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testEqualsDifferentType() {

        DCTermProperty property1 = new DCTermProperty(BASE + NAME,
                                                            LABEL,
                                                            NAME);

        String different = "test";

        assertFalse(property1.equals(different));
    }

    /**
     *  Check equivalence.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testEqualsDifferentUri() {

        DCTermProperty property1 = new DCTermProperty(BASE + NAME,
                                                            LABEL,
                                                            NAME);

        DCTermProperty property2 = new DCTermProperty(BASE + "creator",
                                                            "Creator",
                                                            "creator");

        assertFalse(property1.equals(property2));
    }

    /**
     *  Check equivalence.
     *  @since  Version 0.1 2005-10-21
     */
    public final void testEqualsSameUri() {

        DCTermProperty property1 = new DCTermProperty(BASE + NAME,
                                                            LABEL,
                                                            NAME);

        DCTermProperty property2 = new DCTermProperty(BASE + NAME,
                                                            LABEL,
                                                            NAME);

        assertTrue(property1.equals(property2));

        List list = new Vector();

        list.add(property1);

        assertTrue(list.contains(property2));
    }

    /**
     *  Tear down a test scenario as required.
     *  @since  Version 0.1 2005-10-21
    protected void tearDown() {

    }
     */

    /**
     *  Create a test suite for this test case.
     *  @return A test suite.
     *  @since  Version 0.1 2005-10-21
     */
    public static Test suite() {

        return new TestSuite(DCTermPropertyTest.class);
    }

    /**
     *  Run this test suite as a stand alone application.
     *  @param  args    Any command line arguments to pass
     *          to the test. None required or expected.
     *  @since  Version 0.1 2005-10-21
     */
    public static void main(final String[] args) {

        junit.textui.TestRunner.run(suite());
    }

}
