package com.mkdoc.schema;

/*
    Created:    2005-06-23
    Issued:     2005-06-23
    Modified:   2005-06-28

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

/**
 *  Mock application profile for testing.
 *  @version    0.2 2005-06-28
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockApplicationProfile extends AbstractApplicationProfile {

    /**
     *  Prepare a mock schema for resolution.
     *  @since  Version 0.1 2005-06-23
     */
    public MockApplicationProfile() {

        addSchema(new MockSchema());
    }

    /**
     *  Template method for falling back to profile-specific algorithms.
     *  @param  predicate   A predicate that has not been matched using default
     *          schema prefixes.
     *  @return A predicate URI or <code>null</code> if not matched.
     *  @since  Version 0.2 2005-05-27
     */
    public final String expandPredicateProfile(final String predicate) {

        if (predicate.indexOf("mock.true") > -1) {

            Schema schema = getPrimarySchema("mock");

            return schema.getUri() + "profile/uri";
        }
        else {

            return predicate;
        }
    }

    /**
     *  Template method for falling back to profile-specific algorithms.
     *  @param  scheme  A scheme that has not been matched using default
     *          schema prefixes.
     *  @return A scheme URI or <code>null</code> if not matched.
     *  @since  Version 0.1 2005-06-23
     */
    public final String expandSchemeProfile(final String scheme) {

        if (scheme.indexOf("true") > -1) {

            Schema schema = getPrimarySchema("mock");

            return schema.getUri() + "profile/uri";
        }
        else {

            return scheme;
        }
    }

    /**
     *  Get the primary search property for the schema.
     *  @return The primary search property for the schema.
     *  @since  Version 0.1 2005-06-23
     */
    public final SchemaProperty getPrimarySearchProperty() {

        return getPredicateProperty("mock.examine");
    }

}
