package com.mkdoc.schema;

/*
    Created:    2005-10-19
    Issued:     2005-10-19
    Modified:   2005-10-20

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import java.util.Locale;

/**
 *  A mock schema property for testing.
 *  @version    0.1 2005-10-19
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockSchemaProperty extends AbstractSchemaProperty {

    /**
     *  The schema locale.
     *  @since  Version 0.1 2005-06-16
     */
    private static final Locale LOCALE = new Locale("en", "GB");

    /**
     *  Good citizen constructor.
     *  @param  uri The property URI.
     *  @param  label   The human-readable label.
     *  @param  name    A schema-unique name.
     *  @param  encoding    Whether any encoding scheme applies.
     *  @param  uriEncoding Whether a URI encoding scheme applies.
     */
    public MockSchemaProperty(final String uri,
                              final String label,
                              final String name,
                              final boolean encoding,
                              final boolean uriEncoding) {

        super();

        this.uri = uri;
        this.label = label;
        this.name = name;
        this.encoding = encoding;
        this.uriEncoding = uriEncoding;
    }

    /**
     *  Get the locale of the property for case conversions, etc.
     *  @return The locale for the schema property.
     *  @since  Version 0.7 2005-10-19
     */
    public final Locale getLocale() {

        return LOCALE;
    }

    /**
     *  Get the namespace prefix for the class.
     *  @return The namespace prefix for the class.
     *  @since  Version 0.1 2005-10-19
     */
    public final String getNamespacePrefix() {

        return "test";
    }

    /**
     *  Check equivalance of properties.
     *  @param  other   The object to compare with this.
     *  @return Always returns <code>true</code>.
     *  @since  Version 0.1 2005-10-19
     */
    public final boolean equals(final Object other) {

        return true;
    }

    /**
     *  Get a distinct hash code value.
     *  @return Always returns 1.
     *  @since  Version 0.1 2005-10-19
     */
    public final int hashCode() {

        return 1;
    }

}
