package com.mkdoc.servlet;

/*
    Created:    2005-01-21
    Issued:     2005-01-21
    Modified:   2005-07-22

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import java.util.Enumeration;

import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;

/**
 *  Mock <code>ServletConfig</code> type for testing.
 *  @version    0.2 2005-07-14
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockServletConfig implements ServletConfig {

    /**
     *  Common service properties.
     *  @since  Version 0.1 2005-01-21
     */
    protected MockServiceProperties properties = new MockServiceProperties();

    /**
     *  The servlet context.
     *  @since  Version 0.1 2005-01-21
     */
    protected ServletContext context;

    /**
     *  The servlet name.
     *  @since  Version 0.1 2005-01-21
     */
    protected String servletName;

    /**
     *  Configuration for a named servlet.
     *  @param  servletName The name of the servlet associated with this
     *          configuration.
     *  @since  Version 0.1 2005-01-21
     */
    public MockServletConfig(final String servletName) {

        this.servletName = servletName;
    }

    /**
     *  Get a configuration parameter.
     *  @param  name    The name of the parameter to get.
     *  @return The value of the named parameter or <code>null</code> if not
     *          configured.
     *  @since  Version 0.1 2005-01-21
     */
    public final String getInitParameter(final String name) {

        return properties.getParameter(name);
    }

    /**
     *  Set a configuration parameter by name.
     *  @param  name    The name of the parameter to set.
     *  @param  value   The value of the parameter to set.
     *  @since  Version 0.1 2005-01-21
     */
    public final void setInitParameter(final String name,
                                       final String value) {

        properties.setParameter(name, value);
    }

    /**
     *  Get all configuration parameter names.
     *  @return All parameter names.
     *  @since  Version 0.1 2005-01-21
     */
    public final Enumeration getInitParameterNames() {

        return properties.getParameterNames();
    }

    /**
     *  Get the servlet context.
     *  @return The servlet context.
     *  @since  Version 0.1 2005-01-21
     */
    public final ServletContext getServletContext() {

        return context;
    }

    /**
     *  Set the servlet context.
     *  @param  context The servlet context.
     *  @since  Version 0.1 2005-01-21
     */
    public final void setServletContext(final ServletContext context) {

        this.context = context;
    }

    /**
     *  Get the servlet name.
     *  @return The name of the servlet associated with this
     *          configuration.
     *  @since  Version 0.1 2005-01-21
     */
    public final String getServletName() {

        return servletName;
    }

}
