package com.mkdoc.servlet;

/*
    Created:    2005-07-14
    Issued:     2005-07-22
    Modified:   2005-10-04

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.io.MockInputStream;

import java.io.InputStream;

import java.net.URL;
import java.net.MalformedURLException;

import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;

import javax.servlet.Servlet;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;

/**
 *  A mock <code>ServletContext</code> for testing.
 *  <p>
 *    <em>Incomplete implementation.</em>
 *  </p>
 *  @version    0.2 2005-10-04
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockServletContext extends MockServiceProperties
                                                    implements ServletContext {

    /**
     *  Record a context log.
     *  @since  Version 0.1 2005-07-14
     */
    protected StringBuffer log = new StringBuffer();

    /**
     *  The servlet context name.
     *  @since  Version 0.1 2005-07-14
     */
    protected String contextName = "MockServletContext";

    /**
     *  The server name.
     *  @since  Version 0.1 2005-07-14
     */
    protected String serverName = "MockServletContainer";

    /**
     *  The server major version.
     *  @since  Version 0.1 2005-07-14
     */
    protected static final int MAJ_VERSION = 2;

    /**
     *  The server minor version.
     *  @since  Version 0.1 2005-07-14
     */
    protected static final int MIN_VERSION = 3;

    /**
     *  The resource paths.
     *  @since  Version 0.1 2005-07-14
     */
    protected Set paths = new HashSet();

    /**
     *  A request dispatcher.
     *  @since  Version 0.1 2005-07-14
     */
    protected RequestDispatcher dispatcher;

    /**
     *  The base path for resolving &quot;real&quot; resource paths.
     *  @since  Version 0.2 2005-10-04
     *
     */
    protected String basePath = null;

    /**
     *  Record a context log.
     *  @param  message The message to log.
     *  @since  Version 0.1 2005-07-14
     */
    public final void log(final String message) {

        log.append(message);
        log.append("\n");
    }

    /**
     *  Record a context log.
     *  @param  message The message to log.
     *  @param  throwable   An exception to log.
     *  @since  Version 0.1 2005-07-14
     */
    public final void log(final String message,
                          final Throwable throwable) {

        log(message);
        log(throwable.getMessage());
    }

    /**
     *  Record a context log.
     *  @param  exception   An exception to log.
     *  @param  message A message to log.
     *  @since  Version 0.1 2005-07-14
     */
    public final void log(final Exception exception,
                          final String message) {

        log(message);
        log(exception.getMessage());
    }

    /**
     *  Get the context name.
     *  @return The servlet context name.
     *  @since  Version 0.1 2005-07-14
     */
    public final String getServletContextName() {

        return contextName;
    }

    /**
     *  Set a configuration parameter.
     *  @param  name    The name of the parameter to set.
     *  @param  value   The value to assign to the parameter.
     *  @since  Version 0.1 2005-07-14
     */
    public final void setInitParameter(final String name,
                                       final String value) {

        setParameter(name, value);
    }

    /**
     *  Get a configuration parameter.
     *  @param  name    The name of the parameter to get.
     *  @return The value of the named parameter, or <code>null</code> if not
     *          present.
     *  @since  Version 0.1 2005-07-14
     */
    public final String getInitParameter(final String name) {

        return getParameter(name);
    }

    /**
     *  Servlet references are stored in attributes.
     *  @return All the servlet names loaded in the context.
     *  @since  Version 0.1 2005-07-14
     */
    public final Enumeration getServletNames() {

        return getAttributeNames();
    }

    /**
     *  Get the servlets (stored in attributes).
     *  @return All the servlet instances loaded in the context.
     *  @since  Version 0.1 2005-07-14
     */
    public final Enumeration getServlets() {

        return getAttributes();
    }

    /**
     *  Get a servlet by name (stored in attributes).
     *  @param  name    The name of the servlet to get.
     *  @return The named servlet instance.
     *  @since  Version 0.1 2005-07-14
     */
    public final Servlet getServlet(final String name) {

        return (Servlet) getAttribute(name);
    }

    /**
     *  Get the parameter names.
     *  @return All parameter names in this context.
     *  @since  Version 0.1 2005-07-14
     */
    public final Enumeration getInitParameterNames() {

        return getParameterNames();
    }

    /**
     *  Get the server info.
     *  @return The server name and (servlet API) version.
     *  @since  Version 0.1 2005-07-14
     */
    public final String getServerInfo() {

        return serverName +
               "/" +
               MAJ_VERSION +
               "." +
               MIN_VERSION;
    }

    /**
     *  Get the servlet specification major version number.
     *  @return The major version number of the servlet API supported by the
     *          context.
     *  @since  Version 0.1 2005-07-14
     */
    public final int getMajorVersion() {

        return MAJ_VERSION;
    }

    /**
     *  Get the servlet specification minor version number.
     *  @return The minor version number of the servlet API supported by the
     *          context.
     *  @since  Version 0.1 2005-07-14
     */
    public final int getMinorVersion() {

        return MIN_VERSION;
    }

    /**
     *  Get the MIME type for a file, always returns plain text.
     *  @param  file    The file reference for which to get the MIME type.
     *  @return The MIME type of the resource, fixed "text/plain".
     *  @since  Version 0.1 2005-07-14
     */
    public final String getMimeType(final String file) {

        return "text/plain";
    }

    /**
     *  Get the resource paths.
     *  @param  path    The virtual path to check.
     *  @return All resource paths under the given virtual path.
     *  @since  Version 0.1 2005-07-14
     */
    public final Set getResourcePaths(final String path) {

        return paths;
    }

    /**
     *  Get the resource paths.
     *  @param  path    The path of a servlet resource.
     *  @return A mock input stream.
     *  @since  Version 0.1 2005-07-14
     */
    public final InputStream getResourceAsStream(final String path) {

        return new MockInputStream();
    }

    /**
     *  Get a request dispatcher.
     *  @param  path    The path of the target servlet resource.
     *  @return A request dispatcher for the given path.
     *  @since  Version 0.1 2005-07-14
     */
    public final RequestDispatcher getRequestDispatcher(final String path) {

        return dispatcher;
    }

    /**
     *  Get a named request dispatcher.
     *  @param  name    The name of the target servlet resource.
     *  @return A request dispatcher for the given servlet name.
     *  @since  Version 0.1 2005-07-14
     */
    public final RequestDispatcher getNamedDispatcher(final String name) {

        return dispatcher;
    }

    /**
     *  Get a resource, always throws an exception.
     *  @param  path    The path of the target servlet resource.
     *  @return A reference to the requested servlet resource as a
     *          <code>URL</code> type.
     *  @exception  MalformedURLException   Always thrown by this
     *          implementation.
     *  @since  Version 0.1 2005-07-14
     */
    public final URL getResource(final String path)
        throws MalformedURLException {

        throw new MalformedURLException(
                    "MockServletContext throws MalformedURLException.");
    }

    /**
     *  Get the real path for a path.
     *  @param  path    The virtual path of a resource.
     *  @return The real file system path for the resource.
     *  @since  Version 0.1 2005-07-14
     */
    public final String getRealPath(final String path) {

        if (basePath != null) {

            return basePath + path;
        }
        else {

            return basePath;
        }
    }

    /**
     *  Set the base path for the application context.
     *  @param  basePath    The directory base for the application context,
     *          without a trailing slash.
     *  @since  Version 0.2 2005-10-04
     */
    public final void setBasePath(final String basePath) {

        this.basePath = basePath;
    }

    /**
     *  Get a servlet context.
     *  @param  uripath The path of the resource to look up.
     *  @return The servlet context for the given URI path; this instance.
     *  @since  Version 0.1 2005-07-14
     */
    public final ServletContext getContext(final String uripath) {

        return this;
    }

}
