package com.mkdoc.sesame;

/*
    Created:    2005-01-25
    Issued:     2005-01-25
    Modified:   2005-07-26

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import java.util.List;
import java.util.Vector;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 *  Test suite for <code></code>.
 *  @version    0.1 2005-01-25
 *  @author Philip Shaw <phil@mkdoc.com>
 */
public class SeRQLQueryBuilderTest extends TestCase {

    /**
     *  An expected <code>IllegalArgumentException</code> message.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String MESSAGE_IAE =
    "Should throw an IllegalArgumentException.";

    /**
     *  A <code>dc:title</code> predicate.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String DC_SUBJECT = "dc:subject";

    /**
     *  A target subject term.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String SUBJECT_1 = "Angiostatins";

    /**
     *  A variable name.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String VAR_1 = "targetUri";

    /**
     *  A variable name.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String VAR_2 = "dcSubject";

    /**
     *  A namespace declaration.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String NS_1 = "dc = <http://purl.org/dc/elements/1.1/>";

    /**
     *  A string value.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String VALUE_1 = "value1";

    /**
     *  A string value.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String VALUE_2 = "value2";

    /**
     *  A string value.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String VALUE_3 = "value3";

    /**
     *  An &quot; AND &quot; condition separator string.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String AND = " AND ";

    /**
     *  An &quot; OR &quot; condition separator string.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String OR_COND = " OR ";

    /**
     *  A &quot; LIKE &quot; query keyword.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String LIKE = " LIKE ";

    /**
     *  A &quot; FROM &quot; statement keyword.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String FROM = " FROM ";

    /**
     *  A &quot; WHERE &quot; statement keyword.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String WHERE = " WHERE ";

    /**
     *  A &quot; USING NAMESPACE &quot; clause.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String USING = " USING NAMESPACE ";

    /**
     *  A space character.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String SPACE = " ";

    /**
     *  An <code>SELECT</code> query keyword.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String SELECT = "SELECT ";

    /**
     *  An <code>CONSTRUCT</code> query keyword.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String CONSTRUCT = "CONSTRUCT ";

    /**
     *  An <code>DISTINCT</code> query keyword.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String DISTINCT = "DISTINCT ";

    /**
     *  A path expression.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String EXPR_1 = "{" +
                                        VAR_1 +
                                        "} " +
                                        DC_SUBJECT +
                                        "{" +
                                        VAR_2 +
                                        "}";

    /**
     *  A query condition.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String COND_1 = VAR_2 +
                                        LIKE +
                                        "'" +
                                        SUBJECT_1 +
                                        "'";

    /**
     *  A concatenated value list.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String OR_LIST = VALUE_1 +
                                         OR_COND +
                                         VALUE_2 +
                                         OR_COND +
                                         VALUE_3;

    /**
     *  A minimal select query statement.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String Q_MINIMAL = SELECT +
                                           VAR_1 +
                                           FROM +
                                           EXPR_1;

    /**
     *  A distinct select query statement.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String Q_DISTINCT = SELECT +
                                            DISTINCT +
                                            VAR_1 +
                                            FROM +
                                            EXPR_1;

    /**
     *  A minimal select query with namespace declaration.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String Q_NS = SELECT +
                                      VAR_1 +
                                      FROM +
                                      EXPR_1 +
                                      USING +
                                      NS_1;

    /**
     *  A minimal construct query statement.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String Q_CONSTRUCT = CONSTRUCT +
                                             VAR_1 +
                                             FROM +
                                             EXPR_1;

    /**
     *  A minimal select query statement with condition.
     *  @since  Version 0.1 2005-01-25
     */
    public static final String Q_CONDITION = SELECT +
                                             VAR_1 +
                                             FROM +
                                             EXPR_1 +
                                             WHERE +
                                             COND_1;


    /**
     *  A query builder to test.
     *  @since  Version 0.1 2005-01-25
     */
    protected SeRQLQueryBuilder builder;

    /**
     *  A list of strings.
     *  @since  Version 0.1 2005-01-25
     */
    protected List listMultiple;

    /**
     *  A list of one string.
     *  @since  Version 0.1 2005-01-25
     */
    protected List listOne;

    /**
     *  Named test instance.
     *  @param  name    The name of the test case.
     *  @since  Version 0.1 2005-01-25
     */
    public SeRQLQueryBuilderTest(final String name) {

        super(name);
    }

    /**
     *  Set up a test scenario as required.
     *  @since  Version 0.1 2005-
     */
    protected final void setUp() {

        builder = new SeRQLQueryBuilder();

        listMultiple = new Vector();

        listMultiple.add(VALUE_1);
        listMultiple.add(VALUE_2);
        listMultiple.add(VALUE_3);

        listOne = new Vector();

        listOne.add(VALUE_1);

    }

    /**
     *  Test to string minimal construct query.
     *  <p>
     *    Note this currently generates an invalid query because the
     *    <code>dc</code> namespace is not declared.
     *  </p>
     *  @since  Version 0.1 2005-01-25
     */
    public final void testToStringConstruct() {

        builder.setQueryType("CONSTRUCT");
        builder.addVariable(VAR_1);
        builder.addExpression(EXPR_1);

        String query = builder.toString();

        assertTrue("Query should equal:\n\n" + Q_CONSTRUCT + "'\n" +
                   "actual query was:\n\n" + query,
                   Q_CONSTRUCT.equals(query));
    }

    /**
     *  Test to string minimal.
     *  <p>
     *    Note this currently generates an invalid query because the
     *    <code>dc</code> namespace is not declared.
     *  </p>
     *  @since  Version 0.1 2005-01-25
     */
    public final void testToStringMinimal() {

        builder.addVariable(VAR_1);
        builder.addExpression(EXPR_1);

        String query = builder.toString();

        assertTrue("Query should equal:\n\n" + Q_MINIMAL + "'\n" +
                   "actual query was:\n\n" + query,
                   Q_MINIMAL.equals(query));
    }

    /**
     *  Test to string with distinct condition.
     *  <p>
     *    Note this currently generates an invalid query because the
     *    <code>dc</code> namespace is not declared.
     *  </p>
     *  @since  Version 0.1 2005-01-25
     */
    public final void testToStringDistinct() {

        builder.setDistinct(true);
        builder.addVariable(VAR_1);
        builder.addExpression(EXPR_1);

        String query = builder.toString();

        assertTrue("Query should equal:\n\n" + Q_DISTINCT + "'\n" +
                   "actual query was:\n\n" + query,
                   Q_DISTINCT.equals(query));
    }

    /**
     *  Test to string with namespace declaration.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testToStringWithNamespace() {

        builder.addNamespace(NS_1);
        builder.addVariable(VAR_1);
        builder.addExpression(EXPR_1);

        String query = builder.toString();

        assertTrue("Query should equal:\n\n" + Q_NS + "'\n" +
                   "actual query was:\n\n" + query,
                   Q_NS.equals(query));
    }

    /**
     *  Test to string minimal.
     *  <p>
     *    Note this currently generates an invalid query because the
     *    <code>dc</code> namespace is not declared.
     *  </p>
     *  @since  Version 0.1 2005-01-25
     */
    public final void testToStringWithCondition() {

        builder.addVariable(VAR_1);
        builder.addExpression(EXPR_1);
        builder.addCondition(COND_1);

        String query = builder.toString();

        assertTrue("Query should equal:\n\n" + Q_CONDITION + "'\n" +
                   "actual query was:\n\n" + query,
                   Q_CONDITION.equals(query));
    }

    /**
     *  Test to string state failure.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testToStringNoVariables() {

        builder.addExpression(EXPR_1);

        try {

            builder.toString();

            fail("Should throw an IllegalStateException.");
        }
        catch (IllegalStateException ise) { }

    }

    /**
     *  Test to string state failure.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testToStringNoExpressions() {

        builder.addVariable(VAR_1);

        try {

            builder.toString();

            fail("Should throw an IllegalStateException.");
        }
        catch (IllegalStateException ise) { }

    }


    /**
     *  Test append a list.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAppendListOneItem() {

        StringBuffer buffer = new StringBuffer();

        builder.appendList(listOne, buffer, OR_COND);

        assertTrue(VALUE_1.equals(buffer.toString()));
    }

    /**
     *  Test append a list.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAppendListMultipleItems() {

        StringBuffer buffer = new StringBuffer();

        builder.appendList(listMultiple, buffer, OR_COND);

        assertTrue(OR_LIST.equals(buffer.toString()));
    }

    /**
     *  Test append a list.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAppendListEmptyList() {

        StringBuffer buffer = new StringBuffer();

        List emptyList = new Vector();

        try {

            builder.appendList(emptyList, buffer, OR_COND);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test add a null variable failure.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAddVariableNull() {

        try {

            builder.addVariable(null);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test add a null expression failure.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAddExpressionNull() {

        try {

            builder.addExpression(null);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test add a null condition failure.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAddConditionNull() {

        try {

            builder.addCondition(null);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test add a null namespace failure.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAddNamespaceNull() {

        try {

            builder.addNamespace(null);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test add a null query type failure.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testSetQueryTypeNull() {

        try {

            builder.setQueryType(null);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test append a list.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAppendListNullList() {

        StringBuffer buffer = new StringBuffer();

        try {

            builder.appendList(null, buffer, OR_COND);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test append a list.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAppendListNullBuffer() {

        try {

            builder.appendList(listOne, null, OR_COND);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Test append a list.
     *  @since  Version 0.1 2005-01-25
     */
    public final void testAppendListNullSeparator() {

        StringBuffer buffer = new StringBuffer();

        try {

            builder.appendList(listOne, buffer, null);

            fail(MESSAGE_IAE);
        }
        catch (IllegalArgumentException iae) { }
    }

    /**
     *  Tear down a test scenario as required.
     *  @since  Version 0.1 2005-
    protected void tearDown() {

    }
     */

    /**
     *  Create a test suite for this test case.
     *  @return A test suite.
     *  @since  Version 0.1 2005-01-25
     */
    public static Test suite() {

        return new TestSuite(SeRQLQueryBuilderTest.class);
    }

    /**
     *  Run this test suite as a stand alone application.
     *  @param  args    Any command line arguments to pass
     *          to the test. None required or expected.
     *  @since  Version 0.1 2005-01-25
     */
    public static void main(final String[] args) {

        junit.textui.TestRunner.run(suite());
    }

}
