package com.mkdoc.store;

/*
    Created:    2005-05-17
    Issued:     2005-05-17
    Modified:   2005-11-01

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.jspider.MockPropertySet;

import com.mkdoc.jspider.AbstractMKDocPlugin;

import com.mkdoc.util.ApplicationContext;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 *  Test suite for <code>StoreManagerFactory</code>.
 *  @version    0.5 2005-11-01
 *  @author Philip Shaw <phil@mkdoc.com>
 */
public class StoreManagerFactoryTest extends TestCase {

    /**
     *  An expected <code>IllegalArgumentException</code> message.
     *  @since  Version 0.1 2005-05-17
     */
    public static final String EXPECTED_IAE =
    "Should throw an IllegalArgumentException.";

    /**
     *  An expected <code>StoreException</code> message.
     *  @since  Version 0.1 2005-05-17
     */
    public static final String EXPECTED_SE =
    "Should throw a StoreException.";

    /**
     *  The manager property set key.
     *  @since  Version 0.1 2005-05-17
     */
    public static final String MANAGER = "manager";
    /**
     *  An object manager class name to load.
     *  @since  Version 0.1 2005-05-17
     */
    protected static final String OBJECT_CLASS =
    "com.mkdoc.store.MockObjectManager";

    /**
     *  A predicate manager class name to load.
     *  @since  Version 0.1 2005-05-17
     */
    protected static final String PRED_CLASS =
    "com.mkdoc.store.MockPredicateManager";

    /**
     *  A subject manager class name to load.
     *  @since  Version 0.1 2005-05-17
     */
    protected static final String SUBJ_CLASS =
    "com.mkdoc.store.MockSubjectManager";

    /**
     *  A subject manager class name to load.
     *  @since  Version 0.4 2005-07-19
     */
    protected static final String QURY_CLASS =
    "com.mkdoc.store.MockStoreQueryManager";

    /**
     *  A subject manager class name to load.
     *  @since  Version 0.2 2005-06-06
     */
    protected static final String FILE_CLASS =
    "com.mkdoc.store.MockFileStoreManager";

    /**
     *  A store manager class name to load.
     *  @since  Version 0.1 2005-05-17
     */
    protected static final String STORE_CLASS =
    "com.mkdoc.store.MockStoreManager";

    /**
     *  A &quot;bad&quot; manager class name to load.
     *  @since  Version 0.1 2005-05-17
     */
    protected static final String BAD_CLASS =
    "com.mkdoc.store.MockManagerNoConstructor";

    /**
     *  Named test instance.
     *  @param  name    The name of the test case.
     *  @since  Version 0.1 2005-05-17
     */
    public StoreManagerFactoryTest(final String name) {

        super(name);
    }

    /**
     *  Set up a test scenario as required.
     *  @since  Version 0.1 2005-
    protected void setUp() {

    }
     */

   /**
     *  Get a store query manager.
     *  @since  Version 0.4 2005-07-19
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewStoreQueryManagerSuccess()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(QURY_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        StoreQueryManager manager = null;

        manager = StoreManagerFactory.newStoreQueryManager(context);

        assertTrue((manager != null) &&
                   (manager instanceof MockStoreQueryManager));

    }
*/

    /**
     *  Get a store query manager.
     *  @since  Version 0.4 2005-07-19
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewStoreQueryManagerNullPropertySet()
        throws StoreException, ClassNotFoundException {

        try {

            StoreManagerFactory.newStoreQueryManager(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }
*/

    /**
     *  Get a store query manager.
     *  @since  Version 0.4 2005-07-19
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewStoreQueryManagerWrongType()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(PRED_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newStoreQueryManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }
*/

    /**
     *  Get a store query manager.
     *  @since  Version 0.4 2005-07-19
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewStoreQueryManagerNotConfigured()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newStoreQueryManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }
*/

    /**
     *  Get a file store manager.
     *  @since  Version 0.2 2005-06-06
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewFileStoreManagerSuccess()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(FILE_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        FileStoreManager manager = null;

        manager = StoreManagerFactory.newFileStoreManager(context);

        assertTrue((manager != null) &&
                   (manager instanceof MockFileStoreManager));

    }

    /**
     *  Get a file store manager.
     *  @since  Version 0.2 2005-06-06
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewFileStoreManagerNullPropertySet()
        throws StoreException, ClassNotFoundException {

        try {

            StoreManagerFactory.newFileStoreManager(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Get a file store manager.
     *  @since  Version 0.2 2005-06-06
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewFileStoreManagerWrongType()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(STORE_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newFileStoreManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }

    /**
     *  Get a file store manager.
     *  @since  Version 0.2 2005-06-06
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewFileStoreManagerNotConfigured()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newFileStoreManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }

   /**
     *  Get a subject manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewSubjectManagerSuccess()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(SUBJ_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        SubjectManager manager = null;

        manager = StoreManagerFactory.newSubjectManager(context);

        assertTrue((manager != null) &&
                   (manager instanceof MockSubjectManager));

    }
*/

    /**
     *  Get a subject manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewSubjectManagerNullPropertySet()
        throws StoreException, ClassNotFoundException {

        try {

            StoreManagerFactory.newSubjectManager(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }
*/

    /**
     *  Get a subject manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewSubjectManagerWrongType()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(PRED_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newSubjectManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }
*/

    /**
     *  Get a subject manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewSubjectManagerNotConfigured()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newSubjectManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }
*/

    /**
     *  Get a object manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewObjectManagerSuccess()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(OBJECT_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        ObjectManager manager = null;

        manager = StoreManagerFactory.newObjectManager(context);

        assertTrue((manager != null) &&
                   (manager instanceof MockObjectManager));

    }
*/

    /**
     *  Get a object manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewObjectManagerNullPropertySet()
        throws StoreException, ClassNotFoundException {

        try {

            StoreManagerFactory.newObjectManager(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }
*/

    /**
     *  Get a object manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewObjectManagerWrongType()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(PRED_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newObjectManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }
*/

    /**
     *  Get a object manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewObjectManagerNotConfigured()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newObjectManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }
*/

    /**
     *  Get a predicate manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewPredicateManagerSuccess()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(PRED_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        PredicateManager manager = null;

        manager = StoreManagerFactory.newPredicateManager(context);

        assertTrue((manager != null) &&
                   (manager instanceof MockPredicateManager));
    }
*/

    /**
     *  Get a predicate manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewPredicateManagerNullPropertySet()
        throws StoreException, ClassNotFoundException {

        try {

            StoreManagerFactory.newPredicateManager(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }
*/

    /**
     *  Get a predicate manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewPredicateManagerWrongType()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(OBJECT_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newPredicateManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }
    }
*/

    /**
     *  Get a predicate manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
/*
    public final void testNewPredicateManagerNotConfigured()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newPredicateManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }
    }
*/

    /**
     *  Get a store manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewStoreManagerSuccess()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(STORE_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        StoreManager manager = null;

        manager = StoreManagerFactory.newStoreManager(context);

        assertTrue((manager != null) &&
                   (manager instanceof MockStoreManager));

    }

    /**
     *  Get a store manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewStoreManagerNullPropertySet()
        throws StoreException, ClassNotFoundException {

        try {

            StoreManagerFactory.newStoreManager(null);

            fail(EXPECTED_IAE);
        }
        catch (IllegalArgumentException iae) { }

    }

    /**
     *  Get a store manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewStoreManagerWrongType()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(FILE_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newStoreManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }

    /**
     *  Get a store manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewStoreManagerNotConfigured()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newStoreManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }
    }

    /**
     *  Get a store manager.
     *  @since  Version 0.1 2005-05-17
     *  @exception  StoreException  Should not be thrown by this test.
     *  @exception  ClassNotFoundException  Should not be thrown by this test.
     */
    public final void testNewStoreManagerInstantiationException()
        throws StoreException, ClassNotFoundException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setClass(MANAGER, Class.forName(BAD_CLASS));

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        try {

            StoreManagerFactory.newStoreManager(context);

            fail(EXPECTED_SE);
        }
        catch (StoreException se) { }

    }

    /**
     *  Tear down a test scenario as required.
     *  @since  Version 0.1 2005-
    protected void tearDown() {

    }
     */

    /**
     *  Create a test suite for this test case.
     *  @return A test suite.
     *  @since  Version 0.1 2005-05-17
     */
    public static Test suite() {

        return new TestSuite(StoreManagerFactoryTest.class);
    }

    /**
     *  Run this test suite as a stand alone application.
     *  @param  args    Any command line arguments to pass
     *          to the test. None required or expected.
     *  @since  Version 0.1 2005-05-17
     */
    public static void main(final String[] args) {

        junit.textui.TestRunner.run(suite());
    }

}
