package com.mkdoc.store;

/*
    Created:    2005-05-12
    Issued:     2005-05-12
    Modified:   2005-07-12

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import com.mkdoc.jspider.MockPropertySet;
import com.mkdoc.jspider.AbstractMKDocPlugin;

import com.mkdoc.util.ApplicationContext;

import java.io.File;
import java.io.IOException;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 *  Test suite for <code>TripleFileStoreManager</code>.
 *  @version    0.3 2005-07-12
 *  @author Philip Shaw <phil@mkdoc.com>
 */
public class TripleFileStoreManagerTest extends TestCase {

    /**
     *  The project source directory.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final String HOME = System.getProperty("mkHome");

    /**
     *  A test domain.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final String DOMAIN = System.getProperty("testDomain");

    /**
     *  The default JSpider output directory.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final String OUTPUT = "output";

    /**
     *  A custom output directory.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final String CUSTOM = "custom";

    /**
     *  The custom output path.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final String PATH_CUSTOM = HOME +
                                                File.separator +
                                                OUTPUT +
                                                File.separator +
                                                CUSTOM;

    /**
     *  The default JSpider output directory.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final File DIR_TEST = new File(HOME +
                                                    File.separator +
                                                    OUTPUT);

    /**
     *  A test file.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final String INDEX = "/index.nt";

    /**
     *  A test URL.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final String URL_TEST = "http://" +
                                             DOMAIN +
                                             INDEX;


    /**
     *  A file reference for invalid output file.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final File FILE_OUT = new File(DIR_TEST,
                                                    DOMAIN + INDEX);

    /**
     *  A <code>File</code> representation of the custom
     *  output directory for comparisons.
     *  @since  Version 0.1 2005-05-12
     */
    protected static final File DIR_CUSTOM = new File(PATH_CUSTOM);

    /**
     *  A test range of bytes to write.
     *  @since  Version 0.1 2005-05-12
     */
    public static final int BYTE_RANGE = 256;

    /**
     *  A subject manager to test.
     *  @since  Version 0.1 2005-05-12
     */
    protected TripleFileStoreManager manager;

    /**
     *  Named test instance.
     *  @param  name    The name of the test case.
     *  @since  Version 0.1 2005-05-12
     */
    public TripleFileStoreManagerTest(final String name) {

        super(name);
    }

    /**
     *  Set up a test scenario as required.
     *  @since  Version 0.1 2005-05-12
     */
    protected final void setUp() {

        manager = new TripleFileStoreManager();
    }

    /**
     *  With relative file path and a valid path specification,
     *  should use the specified path.
     *  @exception  IOException In check for canonical
     *          path, or read write operations.
     *  @since  Version 0.1 2005-05-12
     */
    public final void testInitializeOutputPathAbsolute()
        throws IOException {

        MockPropertySet propertySet = new MockPropertySet();

        propertySet.setBoolean(AbstractFileStoreManager.ABSOLUTE, false);
        propertySet.setString(AbstractFileStoreManager.FOLDER, CUSTOM);

        ApplicationContext context = null;

        context = AbstractMKDocPlugin.getApplicationContext(propertySet);

        manager.initialize(context);

        String outPath = manager.outputDir.getCanonicalPath();

        assertTrue("Should use test output directory, '" +
                   DIR_CUSTOM.getCanonicalPath() + "',\n" +
                   "actual output path =             '" +
                   outPath + "'",
                   outPath.equals(DIR_CUSTOM.getCanonicalPath()));
    }

    /**
     *  Purge statements by subject URI.
     *  @exception  IOException Should not be thrown by this test.
     *  @exception  StoreException  Should not be thrown by this test.
     *  @since  Version 0.1 2005-05-12
     */
/* No longer applies

    public final void testPurgeDocumentStatement()
        throws IOException, StoreException {

        MockPropertySet propertySet = new MockPropertySet();

        manager.initialize(propertySet);

        manager.createDirectories(FILE_OUT);

        if ((!FILE_OUT.exists()) &&
            (!FILE_OUT.createNewFile())) {

            fail("Could not create the test file, '" +
                 FILE_OUT.getAbsolutePath() + "'.");
        }

        FileOutputStream outStream = null;

        try {

            outStream = new FileOutputStream(FILE_OUT);

            for (int i = 0; i < BYTE_RANGE; i++) {

                outStream.write(i);
            }
        }
        catch (IOException ioe) {

            fail("Could not write test file, '" +
                 FILE_OUT.getAbsolutePath() + "'.");
        }
        finally {

            outStream.close();
        }

        assertTrue("Test file should exist but does not, '" +
                    FILE_OUT.getAbsolutePath() + "'.",
                    FILE_OUT.exists());

        manager.purgeDocumentStatements(URL_TEST);

        assertFalse("Should have deleted the file but has not, '" +
                    "file path was '" +
                    FILE_OUT.getAbsolutePath() + "'.",
                    FILE_OUT.exists());
    }
*/

    /**
     *  Purge statements by subject URI.
     *  @exception  IOException Should not be thrown by this test.
     *  @exception  StoreException  Should not be thrown by this test.
     *  @since  Version 0.1 2005-05-12
     */
/* No longer applies

    public final void testPurgeDocumentStatementsNotStored()
        throws IOException, StoreException {

        MockPropertySet propertySet = new MockPropertySet();

        manager.initialize(propertySet);

        if ((FILE_OUT.exists()) &&
            (!FILE_OUT.delete())) {

            fail("Could not delete the test file, '" +
                 FILE_OUT.getAbsolutePath() + "'.");
        }

        assertFalse("Test file should not exist but does, '" +
                    FILE_OUT.getAbsolutePath() + "'.",
                    FILE_OUT.exists());

        manager.purgeDocumentStatements(URL_TEST);

        // No side effects, no assertion
    }
*/

    /**
     *  Purge statements with null subject URI.
     *  @exception  IOException Should not be thrown by this test.
     *  @exception  StoreException  Should not be thrown by this test.
     *  @since  Version 0.1 2005-05-12
     */
/* No longer applies

    public final void testPurgeDocumentStatementsNullSubjectUri()
        throws IOException, StoreException {

        try {

            manager.purgeDocumentStatements(null);

            fail("Should throw an IllegalArgumentException.");
        }
        catch (IllegalArgumentException iae) { }
    }
*/

    /**
     *  Bad URL means was not stored in first place.
     *  @exception  StoreException  Should not be thrown by this test.
     *  @since  Version 0.1 2005-05-12
     */
/* No longer applies

    public final void testPurgeDocumentStatementsBadUrl()
        throws StoreException {

        try {

            manager.purgeDocumentStatements("bogus-protocol://phil@mkdoc.com");

            fail("Should throw an IllegalArgumentException.");
        }
        catch (IllegalArgumentException iae) { }
    }
*/

    /**
     *  Get the extension.
     *  @since  Version 0.1 2005-05-12
     */
    public final void testGetExtension() {

        assertTrue(".nt".equals(manager.getExtension()));
    }

    /**
     *  Get shutdown, pure coverage test.
     *  @since  Version 0.1 2005-05-12
     */
    public final void testShutdown() {

        manager.shutdown();

        // Not implemented, no assertion
    }

    /**
     *  Get purge site statements, pure coverage test.
     *  @exception  StoreException  Should not be thrown by this test.
     *  @since  Version 0.1 2005-05-12
     */
/* No longer applies

    public final void testPurgeSiteStatements()
        throws StoreException {

        manager.purgeSiteStatements("http://www.remote.example/");

        // Not implemented, no assertion
    }
*/

    /**
     *  Get add document statements, pure coverage test.
     *  @exception  StoreException  Should not be thrown by this test.
     *  @since  Version 0.1 2005-05-12
     */
/* No longer applies

    public final void testAddDocumentStatements()
        throws StoreException {

        manager.addDocumentStatements(new URIImpl("http//www.remote.example/"),
                                      new GraphImpl());

        // Not implemented, no assertion
    }
*/

    /**
     *  Tear down a test scenario as required.
     *  @since  Version 0.1 2005-
    protected void tearDown() {

    }
     */

    /**
     *  Create a test suite for this test case.
     *  @return A test suite.
     *  @since  Version 0.1 2005-05-12
     */
    public static Test suite() {

        return new TestSuite(TripleFileStoreManagerTest.class);
    }

    /**
     *  Run this test suite as a stand alone application.
     *  @param  args    Any command line arguments to pass
     *          to the test. None required or expected.
     *  @since  Version 0.1 2005-05-12
     */
    public static void main(final String[] args) {

        junit.textui.TestRunner.run(suite());
    }

}
