package com.mkdoc.util;

/*
    Created:    2005-10-18
    Issued:     2005-10-18
    Modified:   2005-10-18

    Author:     Philip Shaw <phil@mkdoc.com>
    Copyright:  (c) 2005 MKDoc Ltd.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA
*/

import java.io.File;

import java.util.Map;
import java.util.Hashtable;

/**
 *  Mock application context for testing.
 *  @version    0.1 2005-10-18
 *  @author     Philip Shaw <phil@mkdoc.com>
 */
public class MockApplicationContext extends AbstractApplicationContext
                                                implements ApplicationContext {

    /**
     *  A map of context parameters, values stored as strings.
     *  @since  Version 0.1 2005-10-18
     */
    private final Map parameters = new Hashtable();

    /**
     *  Get a default store directory.
     *  @since  Version 0.1 2005-10-18
     */
    private final File defaultDir;

    /**
     *  Construct with a default store directory.
     *  @param  defaultDir  A reference to the default store directory.
     *  @since  Version 0.1 2005-10-18
     */
    public MockApplicationContext(final File defaultDir) {

        super();

        this.defaultDir = defaultDir;
    }

    /**
     *  Get a boolean parameter.
     *  @param  name    The name of the parameter to get.
     *  @return The boolean value or <code>false</code> if not found.
     *  @since  Version 0.1 2005-10-18
     */
    public final boolean getBooleanParameter(final String name) {

        String value = (String) parameters.get(name);

        if (value == null) {

            return false;
        }
        else {

            return value.equalsIgnoreCase("true");
        }
    }

    /**
     *  Get a class parameter.
     *  @param  name    The name of the parameter to get.
     *  @return The class or <code>null</code> if there is an error loading
     *          the class.
     *  @since  Version 0.1 2005-10-18
     */
    public final Class getClassParameter(final String name) {

        String value = (String) parameters.get(name);

        try {

            return Class.forName(value);
        }
        catch (Exception e) {

            return null;
        }
    }

    /**
     *  Get a string parameter.
     *  @param  name    The name of the parameter to get.
     *  @return The string or <code>null</code> if not found.
     *  @since  Version 0.1 2005-10-18
     */
    public final String getStringParameter(final String name) {

        return (String) parameters.get(name);
    }

    /**
     *  Get a default store directory.
     *  @return A reference to the default output directory.
     *  @since  Version 0.1 2005-10-18
     */
    protected final File getDefaultStoreDirectory() {

        return defaultDir;
    }

    /**
     *  Set a string parameter.
     *  @param  name    The name of the parameter to set.
     *  @param  value   The value to set.
     *  @since  Version 0.1 2005-10-18
     */
    public final void setParameter(final String name,
                                   final String value) {

        parameters.put(name, value);
    }

}
